@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2015
+    Copyright 2008-2016
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -51,14 +51,11 @@
  * @fileoverview The geometry object Circle is defined in this file. Circle stores all
  * style and functional properties that are required to draw and move a circle on
  * a board.
- * @author graphjs
- * @version 0.1
  */
 
 define([
-    'jxg', 'base/element', 'base/coords', 'base/constants', 'parser/geonext', 'math/geometry', 'math/statistics',
-    'utils/type', 'base/transformation', 'base/point'
-], function (JXG, GeometryElement, Coords, Const, GeonextParser, Geometry, Statistics, Type, Transform, Point) {
+    'jxg', 'base/element', 'base/coords', 'base/constants', 'parser/geonext', 'utils/type'
+], function (JXG, GeometryElement, Coords, Const, GeonextParser, Type) {
 
     "use strict";
 
@@ -151,7 +148,7 @@ define([
             this.gxtterm = par2;
             // Converts GEONExT syntax into JavaScript syntax and generally ensures that the radius is a function
             this.updateRadius = Type.createFunction(par2, this.board, null, true);
-            // First evaluation of the graph
+            // First evaluation of the radius function
             this.updateRadius();
         } else if (method === 'pointLine') {
             // dann ist p2 die Id eines Objekts vom Typ Line!
@@ -300,7 +297,7 @@ define([
 
                 rsq = '((' + p1 + ')-(' + m1 + '))^2 + ((' + p2 + ')-(' + m2 + '))^2';
             } else if (this.method === "pointRadius") {
-                if (typeof this.radius === 'number') {
+                if (Type.isNumber(this.radius)) {
                     rsq = (this.radius * this.radius).toString();
                 }
             } else if (this.method === "pointLine") {
@@ -423,7 +420,7 @@ define([
          * @private
          */
         notifyParents: function (contentStr) {
-            if (typeof contentStr === 'string') {
+            if (Type.isString(contentStr)) {
                 GeonextParser.findDependencies(this, contentStr, this.board);
             }
         },
@@ -477,6 +474,7 @@ define([
          * @deprecated
          */
         getRadius: function () {
+            JXG.deprecated('Circle.getRadius()', 'Circle.Radius()');
             return this.Radius();
         },
 
@@ -631,7 +629,7 @@ define([
         /**
          * Treat the circle as parametric curve and calculates its Z coordinate.
          * @param {Number} t ignored
-         * @return {Number} 1.0
+         * @returns {Number} 1.0
          */
         Z: function (t) {
             return 1.0;
@@ -653,17 +651,37 @@ define([
             return 1.0;
         },
 
+        /**
+         * Circle area
+         * @returns {Number} area of the circle.
+         */
         Area: function () {
             var r = this.Radius();
 
             return r * r * Math.PI;
         },
 
+        /**
+         * Get bounding box of the circle.
+         * @returns {Array} [x1, y1, x2, y2]
+         */
         bounds: function () {
             var uc = this.center.coords.usrCoords,
                 r = this.Radius();
 
             return [uc[1] - r, uc[2] + r, uc[1] + r, uc[2] - r];
+        },
+
+        /**
+         * Get data to construct this element. Data consists of the parent elements
+         * and static data like radius.
+         * @returns {Array} data necessary to construct this element
+         */
+        getParents: function() {
+            if (this.parents.length === 1) {  // i.e. this.method === 'pointRadius'
+                return this.parents.concat(this.radius);
+            }
+            return this.parents;
         }
     });
 
@@ -690,7 +708,7 @@ define([
      * // Create another circle using the above circle
      * var p3 = board.create('point', [3.0, 2.0]),
      *     c2 = board.create('circle', [p3, c1]);
-     * </pre><div id="5f304d31-ef20-4a8e-9c0e-ea1a2b6c79e0" style="width: 400px; height: 400px;"></div>
+     * </pre><div class="jxgbox"id="5f304d31-ef20-4a8e-9c0e-ea1a2b6c79e0" style="width: 400px; height: 400px;"></div>
      * <script type="text/javascript">
      * (function() {
      *   var cex1_board = JXG.JSXGraph.initBoard('5f304d31-ef20-4a8e-9c0e-ea1a2b6c79e0', {boundingbox: [-1, 9, 9, -1], axis: true, showcopyright: false, shownavigation: false});
@@ -708,10 +726,10 @@ define([
      *
      * // Create another circle using the above circle
      * var c2 = board.create('circle', [function() { return [p1.X(), p1.Y() + 1];}, function() { return c1.Radius(); }]);
-     * </pre><div id="54165f60-93b9-441d-8979-ac5d0f193020" style="width: 400px; height: 400px;"></div>
+     * </pre><div class="jxgbox"id="54165f60-93b9-441d-8979-ac5d0f193020" style="width: 400px; height: 400px;"></div>
      * <script type="text/javascript">
      * (function() {
-     * var cex1_board = JXG.JSXGraph.initBoard('54165f60-93b9-441d-8979-ac5d0f193020', {boundingbox: [-1, 9, 9, -1], axis: true, showcopyright: false, shownavigation: false});
+     * var board = JXG.JSXGraph.initBoard('54165f60-93b9-441d-8979-ac5d0f193020', {boundingbox: [-1, 9, 9, -1], axis: true, showcopyright: false, shownavigation: false});
      * var p1 = board.create('point', [2.0, 2.0]);
      * var c1 = board.create('circle', [p1, 3]);
      *
@@ -726,7 +744,7 @@ define([
 
         p = [];
         for (i = 0; i < parents.length; i++) {
-            if (Type.isPointType(parents[i], board)) {
+            if (Type.isPointType(board, parents[i])) {
                 p = p.concat(Type.providePoints(board, [parents[i]], attributes, 'circle', ['center']));
                 if (p[p.length - 1] === false) {
                     throw new Error('JSXGraph: Can\'t create circle from this type. Please provide a point type.');
@@ -774,14 +792,7 @@ define([
         }
 
         el.isDraggable = isDraggable;
-        el.parents = [];
-
-        for (i = 0; i < parents.length; i++) {
-            if (parents[i].id) {
-                el.parents.push(parents[i].id);
-            }
-        }
-
+        el.setParents(p);
         el.elType = 'circle';
         return el;
     };
