@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2015
+    Copyright 2008-2016
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -62,8 +62,8 @@ define([
      * An element containing coords is the basic geometric element. Based on points lines and circles can be constructed which can be intersected
      * which in turn are points again which can be used to construct new lines, circles, polygons, etc. This class holds methods for
      * all kind of coordinate elements like points, texts and images.
-     * @class Creates a new coords element object. Do not use this constructor to create an element. 
-     * 
+     * @class Creates a new coords element object. Do not use this constructor to create an element.
+     *
      * @private
      * @augments JXG.GeometryElement
      * @param {Array} coordinates An array with the affine user coordinates of the point.
@@ -139,6 +139,14 @@ define([
             return this;
         };
 
+        /**
+         * Stores the groups of this element in an array of Group.
+         * @type array
+         * @see JXG.Group
+         * @private
+         */
+        this.groups = [];
+
         /*
          * Do we need this?
          */
@@ -165,14 +173,6 @@ define([
             onPolygon: 'onPolygon'
         });
 
-        /**
-         * Stores the groups of this element in an array of Group.
-         * @type array
-         * @see JXG.Group
-         * @private
-         */
-        this.group = [];
-
         /*
          * this.element may have been set by the object constructor.
          */
@@ -244,7 +244,6 @@ define([
                 slide = this.slideObject;
 
             this.needsUpdateFromParent = false;
-
             if (slide.elementClass === Const.OBJECT_CLASS_CIRCLE) {
                 if (this.visProp.isgeonext) {
                     delta = 1.0;
@@ -489,8 +488,13 @@ define([
                 p1c = slide.point1.coords.usrCoords;
                 p2c = slide.point2.coords.usrCoords;
 
+                // If one of the defining points of the line does not exist,
+                // the glider should disappear
+                if ((p1c[0] === 0 && p1c[1] === 0 && p1c[2] === 0) ||
+                    (p2c[0] === 0 && p2c[1] === 0 && p2c[2] === 0)) {
+                    c = [0, 0, 0];
                 // The second point is an ideal point
-                if (Math.abs(p2c[0]) < Mat.eps) {
+                } else if (Math.abs(p2c[0]) < Mat.eps) {
                     lbda = Math.min(Math.abs(this.position), 1 - Mat.eps);
                     lbda /= (1.0 - lbda);
 
@@ -659,7 +663,9 @@ define([
 
         /**
          * New evaluation of the function term.
-         * This is required for CAS-points: Their XTerm() method is overwritten in {@link #addConstraint}
+         * This is required for CAS-points: Their XTerm() method is
+         * overwritten in {@link JXG.CoordsElement#addConstraint}.
+         *
          * @returns {Number} User coordinate of point in x direction.
          * @private
          */
@@ -669,7 +675,9 @@ define([
 
         /**
          * New evaluation of the function term.
-         * This is required for CAS-points: Their YTerm() method is overwritten in {@link #addConstraint}
+         * This is required for CAS-points: Their YTerm() method is overwritten
+         * in {@link JXG.CoordsElement#addConstraint}.
+         *
          * @returns {Number} User coordinate of point in y direction.
          * @private
          */
@@ -679,7 +687,9 @@ define([
 
         /**
          * New evaluation of the function term.
-         * This is required for CAS-points: Their ZTerm() method is overwritten in {@link #addConstraint}
+         * This is required for CAS-points: Their ZTerm() method is overwritten in
+         * {@link JXG.CoordsElement#addConstraint}.
+         *
          * @returns {Number} User coordinate of point in z direction.
          * @private
          */
@@ -720,13 +730,34 @@ define([
         handleSnapToPoints: function (force) {
             var i, pEl, pCoords,
                 d = 0,
+                len,
                 dMax = Infinity,
-                c = null;
+                c = null,
+                len2, j, ignore = false;
+
+            len = this.board.objectsList.length;
+
+            if (this.visProp.ignoredsnaptopoints) {
+                len2 = this.visProp.ignoredsnaptopoints.length;
+            }
 
             if (this.visProp.snaptopoints || force) {
-                for (i = 0; i < this.board.objectsList.length; i++) {
+                for (i = 0; i < len; i++) {
                     pEl = this.board.objectsList[i];
 
+                    if (this.visProp.ignoredsnaptopoints) {
+                        ignore = false;
+                        for (j = 0; j < len2; j++) {
+                            if (pEl == this.board.select(this.visProp.ignoredsnaptopoints[j])) {
+                                ignore = true;
+                                break;
+                            }
+                        }
+                        if (ignore) {
+                            continue;
+                        }
+                    }
+
                     if (Type.isPoint(pEl) && pEl !== this && pEl.visProp.visible) {
                         pCoords = Geometry.projectPointToPoint(this, pEl, this.board);
                         if (this.visProp.attractorunit === 'screen') {
@@ -751,7 +782,8 @@ define([
         },
 
         /**
-         * Alias for {@link #handleSnapToPoints}.
+         * Alias for {@link JXG.CoordsElement#handleSnapToPoints}.
+         *
          * @param {Boolean} force force snapping independent from what the snaptogrid attribute says
          * @returns {JXG.Point} Reference to this element
          */
@@ -763,7 +795,7 @@ define([
          * A point can change its type from free point to glider
          * and vice versa. If it is given an array of attractor elements
          * (attribute attractors) and the attribute attractorDistance
-         * then the pint will be made a glider if it less than attractorDistance
+         * then the point will be made a glider if it less than attractorDistance
          * apart from one of its attractor elements.
          * If attractorDistance is equal to zero, the point stays in its
          * current form.
@@ -772,6 +804,7 @@ define([
         handleAttractors: function () {
             var i, el, projCoords,
                 d = 0.0,
+                projection,
                 len = this.visProp.attractors.length;
 
             if (this.visProp.attractordistance === 0.0) {
@@ -785,7 +818,17 @@ define([
                     if (Type.isPoint(el)) {
                         projCoords = Geometry.projectPointToPoint(this, el, this.board);
                     } else if (el.elementClass === Const.OBJECT_CLASS_LINE) {
-                        projCoords = Geometry.projectPointToLine(this, el, this.board);
+                        projection = Geometry.projectCoordsToSegment(
+                                    this.coords.usrCoords,
+                                    el.point1.coords.usrCoords,
+                                    el.point2.coords.usrCoords);
+                        if (!el.visProp.straightfirst && projection[1] < 0.0) {
+                            projCoords = el.point1.coords;
+                        } else if (!el.visProp.straightlast && projection[1] > 1.0) {
+                            projCoords = el.point2.coords;
+                        } else {
+                            projCoords = new Coords(Const.COORDS_BY_USER, projection[0], this.board);
+                        }
                     } else if (el.elementClass === Const.OBJECT_CLASS_CIRCLE) {
                         projCoords = Geometry.projectPointToCircle(this, el, this.board);
                     } else if (el.elementClass === Const.OBJECT_CLASS_CURVE) {
@@ -822,26 +865,13 @@ define([
          * @param {Number} method The type of coordinates used here.
          * Possible values are {@link JXG.COORDS_BY_USER} and {@link JXG.COORDS_BY_SCREEN}.
          * @param {Array} coords coordinates <tt>([z], x, y)</tt> in screen/user units
-         * @param {Array} lastPosition (optional) coordinates <tt>(x, y)</tt> in screen units of the last position.
-         * Usually this is the position where the last drag event had occurred. This is needed to prevent jumps
-         * to the lower left corner when dragging an image.
          * @returns {JXG.Point} this element
          */
-        setPositionDirectly: function (method, coords, lastPosition) {
-            var i, offset, c, dc,
+        setPositionDirectly: function (method, coords) {
+            var i, c, dc,
                 oldCoords = this.coords,
                 newCoords;
 
-            // Correct offset for large objects like images and texts to prevent that the
-            // corner of the object jumps to the mouse pointer.
-            if (Type.exists(lastPosition) &&
-                    !this.visProp.snaptogrid &&
-                    !this.visProp.snaptopoints &&
-                    this.visProp.attractors.length === 0) {
-                offset = Statistics.subtract(this.coords.scrCoords.slice(1), lastPosition);
-                coords = Statistics.add(coords, offset);
-            }
-
             if (this.relativeCoords) {
                 c = new Coords(method, coords, this.board);
                 if (this.visProp.islabel) {
@@ -862,25 +892,20 @@ define([
             this.handleSnapToPoints();
             this.handleAttractors();
 
-            if (this.group.length === 0) {
-                // Here used to be the update of the groups. I'm not sure why we don't need to execute
-                // the else branch if there are groups defined on this point, hence I'll let the if live.
-
-                // Update the initial coordinates. This is needed for free points
-                // that have a transformation bound to it.
-                for (i = this.transformations.length - 1; i >= 0; i--) {
-                    if (method === Const.COORDS_BY_SCREEN) {
-                        newCoords = (new Coords(method, coords, this.board)).usrCoords;
-                    } else {
-                        if (coords.length === 2) {
-                            coords = [1].concat(coords);
-                        }
-                        newCoords = coords;
+            // Update the initial coordinates. This is needed for free points
+            // that have a transformation bound to it.
+            for (i = this.transformations.length - 1; i >= 0; i--) {
+                if (method === Const.COORDS_BY_SCREEN) {
+                    newCoords = (new Coords(method, coords, this.board)).usrCoords;
+                } else {
+                    if (coords.length === 2) {
+                        coords = [1].concat(coords);
                     }
-                    this.initialCoords.setCoordinates(Const.COORDS_BY_USER, Mat.matVecMult(Mat.inverse(this.transformations[i].matrix), newCoords));
+                    newCoords = coords;
                 }
-                this.prepareUpdate().update();
+                this.initialCoords.setCoordinates(Const.COORDS_BY_USER, Mat.matVecMult(Mat.inverse(this.transformations[i].matrix), newCoords));
             }
+            this.prepareUpdate().update();
 
             // If the user suspends the board updates we need to recalculate the relative position of
             // the point on the slide object. this is done in updateGlider() which is NOT called during the
@@ -896,7 +921,7 @@ define([
          * Translates the point by <tt>tv = (x, y)</tt>.
          * @param {Number} method The type of coordinates used here.
          * Possible values are {@link JXG.COORDS_BY_USER} and {@link JXG.COORDS_BY_SCREEN}.
-         * @param {Number} tv (x, y)
+         * @param {Array} tv (x, y)
          * @returns {JXG.Point}
          */
         setPositionByTransform: function (method, tv) {
@@ -922,13 +947,10 @@ define([
          * @param {Number} method The type of coordinates used here.
          * Possible values are {@link JXG.COORDS_BY_USER} and {@link JXG.COORDS_BY_SCREEN}.
          * @param {Array} coords coordinates in screen/user units
-         * @param {Array} lastPosition (optional) coordinates <tt>(x, y)</tt> in screen units of the last position.
-         * Usually this is the position where the last drag event had occurred. This is needed to prevent jumps
-         * to the lower left corner when dragging an image.
          * @returns {JXG.Point}
          */
-        setPosition: function (method, coords, lastPosition) {
-            return this.setPositionDirectly(method, coords, lastPosition);
+        setPosition: function (method, coords) {
+            return this.setPositionDirectly(method, coords);
         },
 
         /**
@@ -952,7 +974,25 @@ define([
          * @param {String|Object} slide The object the point will be bound to.
          */
         makeGlider: function (slide) {
-            var slideobj = this.board.select(slide);
+            var slideobj = this.board.select(slide),
+                onPolygon = false,
+                min,
+                i,
+                dist;
+
+            if (slideobj.type === Const.OBJECT_TYPE_POLYGON){
+                // Search for the closest side of the polygon.
+                min = Number.MAX_VALUE;
+                for (i = 0; i < slideobj.borders.length; i++){
+                    dist = JXG.Math.Geometry.distPointLine(this.coords.usrCoords, slideobj.borders[i].stdform);
+                    if (dist < min){
+                        min = dist;
+                        slide = slideobj.borders[i];
+                    }
+                }
+            	slideobj = this.board.select(slide);
+            	onPolygon = true;
+            }
 
             /* Gliders on Ticks are forbidden */
             if (!Type.exists(slideobj)) {
@@ -970,6 +1010,7 @@ define([
             this.visProp.snapwidth = -1;          // By default, deactivate snapWidth
             this.slideObject.addChild(this);
             this.isDraggable = true;
+            this.onPolygon = onPolygon;
 
             this.generatePolynomial = function () {
                 return this.slideObject.generatePolynomial(this);
@@ -1131,7 +1172,7 @@ define([
             for (i = 0; i < terms.length; i++) {
                 v = terms[i];
 
-                if (typeof v === 'string') {
+                if (Type.isString(v)) {
                     // Convert GEONExT syntax into JavaScript syntax
                     //t  = JXG.GeonextParser.geonext2JS(v, this.board);
                     //newfuncs[i] = new Function('','return ' + t + ';');
@@ -1141,12 +1182,12 @@ define([
                     if (terms.length === 2) {
                         this[what[i] + 'jc'] = terms[i];
                     }
-                } else if (typeof v === 'function') {
+                } else if (Type.isFunction(v)) {
                     newfuncs[i] = v;
-                } else if (typeof v === 'number') {
+                } else if (Type.isNumber(v)) {
                     newfuncs[i] = makeConstFunction(v);
                 // Slider
-                } else if (typeof v === 'object' && typeof v.Value === 'function') {
+            } else if (Type.isObject(v) && Type.isFunction(v.Value)) {
                     newfuncs[i] = makeSliderFunction(v);
                 }
 
@@ -1171,7 +1212,7 @@ define([
                 this.XEval = newfuncs[0];
                 this.YEval = newfuncs[1];
 
-                this.parents = [newfuncs[0].origin, newfuncs[1].origin];
+                this.setParents([newfuncs[0].origin, newfuncs[1].origin]);
 
                 this.updateConstraint = function () {
                     this.coords.setCoordinates(Const.COORDS_BY_USER, [this.XEval(), this.YEval()]);
@@ -1182,7 +1223,7 @@ define([
                 this.XEval = newfuncs[1];
                 this.YEval = newfuncs[2];
 
-                this.parents = [newfuncs[0].origin, newfuncs[1].origin, newfuncs[2].origin];
+                this.setParents([newfuncs[0].origin, newfuncs[1].origin, newfuncs[2].origin]);
 
                 this.updateConstraint = function () {
                     this.coords.setCoordinates(Const.COORDS_BY_USER, [this.ZEval(), this.XEval(), this.YEval()]);
@@ -1218,7 +1259,9 @@ define([
                 this.relativeCoords = new Coords(Const.COORDS_BY_USER, coordinates, this.board);
             }
             this.element.addChild(this);
-            this.addParents(this.element);
+            if (isLabel) {
+                this.addParents(this.element);
+            }
 
             this.XEval = function () {
                 var sx, coords, anchor;
@@ -1345,8 +1388,8 @@ define([
         /**
          * Starts an animation which moves the point along a given path in given time.
          * @param {Array|function} path The path the point is moved on.
-         * This can be either an array of arrays containing x and y values of the points of
-         * the path, or  function taking the amount of elapsed time since the animation
+         * This can be either an array of arrays or containing x and y values of the points of
+         * the path, or an array of points, or a function taking the amount of elapsed time since the animation
          * has started and returns an array containing a x and a y value or NaN.
          * In case of NaN the animation stops.
          * @param {Number} time The time in milliseconds in which to finish the animation
@@ -1354,7 +1397,7 @@ define([
          * @param {function} [options.callback] A function that is called as soon as the animation is finished.
          * @param {Boolean} [options.interpolate=true] If <tt>path</tt> is an array moveAlong()
          * will interpolate the path
-         * using {@link JXG.Math.Numerics#Neville}. Set this flag to false if you don't want to use interpolation.
+         * using {@link JXG.Math.Numerics.Neville}. Set this flag to false if you don't want to use interpolation.
          * @returns {JXG.Point} Reference to the point.
          */
         moveAlong: function (path, time, options) {
@@ -1365,6 +1408,7 @@ define([
                 p = [],
                 delay = this.board.attr.animationdelay,
                 steps = time / delay,
+                len, pos, part,
 
                 makeFakeFunction = function (i, j) {
                     return function () {
@@ -1373,7 +1417,8 @@ define([
                 };
 
             if (Type.isArray(path)) {
-                for (i = 0; i < path.length; i++) {
+                len = path.length;
+                for (i = 0; i < len; i++) {
                     if (Type.isPoint(path[i])) {
                         p[i] = path[i];
                     } else {
@@ -1399,11 +1444,24 @@ define([
                         interpath[i][1] = neville[1]((steps - i) / steps * neville[3]());
                     }
                 } else {
+                    len = path.length - 1;
+                    for (i = 0; i < steps; ++i) {
+                        pos = Math.floor(i / steps * len);
+                        part = i / steps * len - pos;
+
+                        interpath[i] = [];
+                        interpath[i][0] = (1.0 - part) * p[pos].X() + part * p[pos + 1].X();
+                        interpath[i][1] = (1.0 - part) * p[pos].Y() + part * p[pos + 1].Y();
+                    }
+                    interpath.push([p[len].X(), p[len].Y()]);
+                    interpath.reverse();
+                    /*
                     for (i = 0; i < steps; i++) {
                         interpath[i] = [];
                         interpath[i][0] = path[Math.floor((steps - i) / steps * (path.length - 1))][0];
                         interpath[i][1] = path[Math.floor((steps - i) / steps * (path.length - 1))][1];
                     }
+                    */
                 }
 
                 this.animationPath = interpath;
@@ -1458,7 +1516,8 @@ define([
                 return this.board.update(this);
             }
 
-            if (Math.abs(dX) < Mat.eps && Math.abs(dY) < Mat.eps) {
+            // In case there is no callback and we are already at the endpoint we can stop here
+            if (!Type.exists(options.callback) && Math.abs(dX) < Mat.eps && Math.abs(dY) < Mat.eps) {
                 return this;
             }
 
@@ -1511,7 +1570,7 @@ define([
                 };
 
             // support legacy interface where the third parameter was the number of repeats
-            if (typeof options === 'number') {
+            if (Type.isNumber(options)) {
                 options = {repeat: options};
             } else {
                 options = options || {};
@@ -1627,16 +1686,16 @@ define([
             return this.coords;
         },
 
+        // documented in element.js
         getParents: function () {
             var p = [this.Z(), this.X(), this.Y()];
 
-            if (this.parents) {
+            if (this.parents.length !== 0) {
                 p = this.parents;
             }
 
             if (this.type === Const.OBJECT_TYPE_GLIDER) {
                 p = [this.X(), this.Y(), this.slideObject.id];
-
             }
 
             return p;
@@ -1664,13 +1723,13 @@ define([
         var el, isConstrained = false, i;
 
         for (i = 0; i < coords.length; i++) {
-            if (typeof coords[i] === 'function' || typeof coords[i] === 'string') {
+            if (Type.isFunction(coords[i]) || Type.isString(coords[i])) {
                 isConstrained = true;
             }
         }
 
         if (!isConstrained) {
-            if ((Type.isNumber(coords[0])) && (Type.isNumber(coords[1]))) {
+            if (Type.isNumber(coords[0]) && Type.isNumber(coords[1])) {
                 el = new Callback(board, coords, attr, arg1, arg2);
 
                 if (Type.exists(attr.slideobject)) {
@@ -1680,13 +1739,15 @@ define([
                     el.baseElement = el;
                 }
                 el.isDraggable = true;
-            } else if ((typeof coords[0] === 'object') && (typeof coords[1] === 'object')) {
+            } else if (Type.isObject(coords[0]) &&
+                (Type.isObject(coords[1]) || // Transformation
+                 (Type.isArray(coords[1]) && coords[1].length > 0 && Type.isObject(coords[1][0]))
+                )) { // Array of transformations
+
                 // Transformation
                 el = new Callback(board, [0, 0], attr, arg1, arg2);
                 el.addTransform(coords[0], coords[1]);
                 el.isDraggable = false;
-
-                //el.parents = [coords[0].id];
             } else {
                 return false;
             }
