@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2015
+    Copyright 2008-2016
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -118,7 +118,6 @@ define([
 
         /**
          * Keeps track of all objects drawn as part of the trace of the element.
-         * @see JXG.GeometryElement#traced
          * @see JXG.GeometryElement#clearTrace
          * @see JXG.GeometryElement#numTraces
          * @type Object
@@ -127,7 +126,6 @@ define([
 
         /**
          * Counts the number of objects drawn as part of the trace of the element.
-         * @see JXG.GeometryElement#traced
          * @see JXG.GeometryElement#clearTrace
          * @see JXG.GeometryElement#traces
          * @type Number
@@ -239,7 +237,7 @@ define([
          * @type Object
          */
         this.methodMap = {
-            setLabel: 'setLabelText',
+            setLabel: 'setLabel',
             label: 'label',
             setName: 'setName',
             getName: 'getName',
@@ -410,10 +408,45 @@ define([
         },
 
         /**
-         * Adds ids of elements to the array this.parents.
+         * Adds ids of elements to the array this.parents. This method needs to be called if some dependencies
+         * can not be detected automatically by JSXGraph. For example if a function graph is given by a function
+         * which referes to coordinates of a point, calling addParents() is necessary.
+         *
          * @param {Array} parents Array of elements or ids of elements.
          * Alternatively, one can give a list of objects as parameters.
          * @returns {JXG.Object} reference to the object itself.
+         *
+         * @example
+         * // Movable function graph
+         * var A = board.create('point', [1, 0], {name:'A'}),
+         *     B = board.create('point', [3, 1], {name:'B'}),
+         *     f = board.create('functiongraph', function(x) {
+         *          var ax = A.X(),
+         *              ay = A.Y(),
+         *              bx = B.X(),
+         *              by = B.Y(),
+         *              a = (by - ay) / ( (bx - ax) * (bx - ax) );
+         *           return a * (x - ax) * (x - ax) + ay;
+         *      }, {fixed: false});
+         * f.addParents([A, B]);
+         * </pre><div class="jxgbox"id="7c91d4d2-986c-4378-8135-24505027f251" style="width: 400px; height: 400px;"></div>
+         * <script type="text/javascript">
+         * (function() {
+         *   var board = JXG.JSXGraph.initBoard('7c91d4d2-986c-4378-8135-24505027f251', {boundingbox: [-1, 9, 9, -1], axis: true, showcopyright: false, shownavigation: false});
+         *   var A = board.create('point', [1, 0], {name:'A'}),
+         *       B = board.create('point', [3, 1], {name:'B'}),
+         *       f = board.create('functiongraph', function(x) {
+         *            var ax = A.X(),
+         *                ay = A.Y(),
+         *                bx = B.X(),
+         *                by = B.Y(),
+         *                a = (by - ay) / ( (bx - ax) * (bx - ax) );
+         *             return a * (x - ax) * (x - ax) + ay;
+         *        }, {fixed: false});
+         *   f.addParents([A, B]);
+         * })();
+         * </script><pre>
+         *
          **/
         addParents: function (parents) {
             var i, len, par;
@@ -426,22 +459,33 @@ define([
 
             len = par.length;
             for (i = 0; i < len; ++i) {
-                if (Type.isId(par[i])) {
+                if (Type.isId(this.board, par[i])) {
                     this.parents.push(par[i]);
                 } else if (Type.exists(par[i].id)) {
                     this.parents.push(par[i].id);
                 }
             }
-
             this.parents = Type.uniqueArray(this.parents);
         },
 
+        /**
+         * Sets ids of elements to the array this.parents.
+         * First, this.parents is cleared. See {@link JXG.GeometryElement#addParents}.
+         * @param {Array} parents Array of elements or ids of elements.
+         * Alternatively, one can give a list of objects as parameters.
+         * @returns {JXG.Object} reference to the object itself.
+         **/
+        setParents: function(parents) {
+            this.parents = [];
+            this.addParents(parents);
+        },
+
         /**
          * Remove an element as a child from the current element.
          * @param {JXG.GeometryElement} obj The dependent object.
          */
         removeChild: function (obj) {
-            var el, el2;
+            //var el, el2;
 
             delete this.childElements[obj.id];
             this.removeDescendants(obj);
@@ -495,7 +539,7 @@ define([
         /**
          * Counts the direct children of an object without counting labels.
          * @private
-         * @return {number} Number of children
+         * @returns {number} Number of children
          */
         countChildren: function () {
             var prop, d,
@@ -520,7 +564,8 @@ define([
 
         /**
          * Add transformations to this element.
-         * @param {JXG.Transformation|Array} transform Either one {@link JXG.Transformation} or an array of {@link JXG.Transformation}s.
+         * @param {JXG.Transformation|Array} transform Either one {@link JXG.Transformation}
+         * or an array of {@link JXG.Transformation}s.
          * @returns {JXG.GeometryElement} Reference to the element.
          */
         addTransform: function (transform) {
@@ -528,26 +573,28 @@ define([
         },
 
         /**
-         * Decides whether an element can be dragged. This is used in {@link JXG.GeometryElement#setPositionDirectly} methods
+         * Decides whether an element can be dragged. This is used in
+         * {@link JXG.GeometryElement#setPositionDirectly} methods
          * where all parent elements are checked if they may be dragged, too.
          * @private
-         * @return {boolean}
+         * @returns {boolean}
          */
         draggable: function () {
             return this.isDraggable && !this.visProp.fixed &&
-                !this.visProp.frozen && this.type !== Const.OBJECT_TYPE_GLIDER;
+                /*!this.visProp.frozen &&*/ this.type !== Const.OBJECT_TYPE_GLIDER;
         },
 
         /**
          * Translates the object by <tt>(x, y)</tt>. In case the element is defined by points, the defining points are
          * translated, e.g. a circle constructed by a center point and a point on the circle line.
-         * @param {Number} method The type of coordinates used here. 
+         * @param {Number} method The type of coordinates used here.
          * Possible values are {@link JXG.COORDS_BY_USER} and {@link JXG.COORDS_BY_SCREEN}.
          * @param {Array} coords array of translation vector.
          * @returns {JXG.GeometryElement} Reference to the element object.
          */
         setPosition: function (method, coords) {
-            var parents = [], el, i, len, t;
+            var parents = [],
+                el, i, len, t;
 
             if (!JXG.exists(this.parents)) {
                 return this;
@@ -591,7 +638,7 @@ define([
             }
 
             /*
-             * If - against the default configuration - defining gliders are marked as 
+             * If - against the default configuration - defining gliders are marked as
              * draggable, then their position has to be updated now.
              */
             for (i = 0; i < len; ++i) {
@@ -605,7 +652,8 @@ define([
 
         /**
          * Moves an by the difference of two coordinates.
-         * @param {Number} method The type of coordinates used here. Possible values are {@link JXG.COORDS_BY_USER} and {@link JXG.COORDS_BY_SCREEN}.
+         * @param {Number} method The type of coordinates used here.
+         * Possible values are {@link JXG.COORDS_BY_USER} and {@link JXG.COORDS_BY_SCREEN}.
          * @param {Array} coords coordinates in screen/user units
          * @param {Array} oldcoords previous coordinates in screen/user units
          * @returns {JXG.GeometryElement} this element
@@ -809,6 +857,18 @@ define([
             return properties;
         },
 
+        /**
+         * Sets a label and it's text
+         * If label doesn't exist, it creates one
+         * @param {String} str
+         */
+        setLabel: function (str) {
+            if (!this.hasLabel) {
+                this.setAttribute({'withlabel': true});
+            }
+            this.setLabelText(str);
+        },
+
         /**
          * Updates the element's label text, strips all html.
          * @param {String} str
@@ -839,7 +899,10 @@ define([
          * Deprecated alias for {@link JXG.GeometryElement#setAttribute}.
          * @deprecated Use {@link JXG.GeometryElement#setAttribute}.
          */
-        setProperty: JXG.shortcut(JXG.GeometryElement.prototype, 'setAttribute'),
+        setProperty: function () {
+            JXG.deprecated('setProperty()', 'setAttribute()');
+            this.setAttribute.apply(this, arguments);
+        },
 
         /**
          * Sets an arbitrary number of attributes.
@@ -858,12 +921,7 @@ define([
          */
         setAttribute: function (attributes) {
             var i, key, value, arg, opacity, pair, oldvalue,
-                properties = {},
-                makeTicksFunction = function (v) {
-                    return function (i) {
-                        return v;
-                    };
-                };
+                properties = {};
 
             // normalize the user input
             for (i = 0; i < arguments.length; i++) {
@@ -921,7 +979,7 @@ define([
                         }
                         break;
                     case 'infoboxtext':
-                        if (typeof value === 'string') {
+                        if (Type.isString(value)) {
                             this.infoboxText = value;
                         } else {
                             this.infoboxText = false;
@@ -996,12 +1054,12 @@ define([
                         }
                         break;
                     case 'ticksdistance':
-                        if (this.type === Const.OBJECT_TYPE_TICKS && typeof value === 'number') {
-                            this.ticksFunction = makeTicksFunction(value);
+                        if (this.type === Const.OBJECT_TYPE_TICKS && Type.isNumber(value)) {
+                            this.ticksFunction = this.makeTicksFunction(value);
                         }
                         break;
                     case 'generatelabelvalue':
-                        if (this.type === Const.OBJECT_TYPE_TICKS && typeof value === 'function') {
+                        if (this.type === Const.OBJECT_TYPE_TICKS && Type.isFunction(value)) {
                             this.generateLabelValue = value;
                         }
                         break;
@@ -1010,6 +1068,12 @@ define([
                             this.onPolygon = !!value;
                         }
                         break;
+                    case 'disabled':
+                        // button, checkbox, input. Is not available on initial call.
+                        if (JXG.exists(this.rendNodeTag)) {
+                            this.rendNodeTag.disabled = !!value;
+                        }
+                        break;
                     default:
                         if (Type.exists(this.visProp[key]) && (!JXG.Validator[key] || (JXG.Validator[key] &&
                                 JXG.Validator[key](value)) || (JXG.Validator[key] &&
@@ -1038,7 +1102,10 @@ define([
          * Deprecated alias for {@link JXG.GeometryElement#getAttribute}.
          * @deprecated Use {@link JXG.GeometryElement#getAttribute}.
          */
-        getProperty: JXG.shortcut(JXG.GeometryElement.prototype, 'getAttribute'),
+        getProperty: function () {
+            JXG.deprecated('getProperty()', 'getAttribute()');
+            this.getProperty.apply(this, arguments);
+        },
 
         /**
          * Get the value of the property <tt>key</tt>.
@@ -1071,8 +1138,10 @@ define([
         },
 
         /**
-         * Set the dash style of an object. See {@link #dash} for a list of available dash styles.
-         * You should use {@link #setAttribute} instead of this method.
+         * Set the dash style of an object. See {@link JXG.GeometryElement#dash}
+         * for a list of available dash styles.
+         * You should use {@link JXG.GeometryElement#setAttribute} instead of this method.
+         *
          * @param {number} dash Indicates the new dash style
          * @private
          */
@@ -1167,7 +1236,7 @@ define([
 
                 if (this.visProp.withlabel) {
                     this.label = JXG.elements.text(this.board, [0, 0, function () {
-                        if (typeof that.name === 'function') {
+                        if (Type.isFunction(that.name)) {
                             return that.name();
                         }
                         return that.name;
@@ -1260,7 +1329,8 @@ define([
 
         /**
          * Dimensions of the smallest rectangle enclosing the element.
-         * @returns {Array} The coordinates of the enclosing rectangle in a format like the bounding box in {@link JXG.Board#setBoundingBox}.
+         * @returns {Array} The coordinates of the enclosing rectangle in a format
+         * like the bounding box in {@link JXG.Board#setBoundingBox}.
          */
         bounds: function () {
             return [0, 0, 0, 0];
@@ -1280,7 +1350,7 @@ define([
          * @type string
          * @private
          * @ignore
-         * @return JSON string containing element's properties.
+         * @returns JSON string containing element's properties.
          */
         toJSON: function () {
             var vis, key,
@@ -1363,9 +1433,10 @@ define([
          * Set the highlightStrokeColor of an element
          * @param {String} sColor String which determines the stroke color of an object when its highlighted.
          * @see JXG.GeometryElement#highlightStrokeColor
-         * @deprecated Use {@link #setAttribute}
+         * @deprecated Use {@link JXG.GeometryElement#setAttribute}
          */
         highlightStrokeColor: function (sColor) {
+            JXG.deprecated('highlightStrokeColor()', 'setAttribute()');
             this.setAttribute({highlightStrokeColor: sColor});
             return this;
         },
@@ -1374,9 +1445,10 @@ define([
          * Set the strokeColor of an element
          * @param {String} sColor String which determines the stroke color of an object.
          * @see JXG.GeometryElement#strokeColor
-         * @deprecated Use {@link #setAttribute}
+         * @deprecated Use {@link JXG.GeometryElement#setAttribute}
          */
         strokeColor: function (sColor) {
+            JXG.deprecated('strokeColor()', 'setAttribute()');
             this.setAttribute({strokeColor: sColor});
             return this;
         },
@@ -1385,9 +1457,10 @@ define([
          * Set the strokeWidth of an element
          * @param {Number} width Integer which determines the stroke width of an outline.
          * @see JXG.GeometryElement#strokeWidth
-         * @deprecated Use {@link #setAttribute}
+         * @deprecated Use {@link JXG.GeometryElement#setAttribute}
          */
         strokeWidth: function (width) {
+            JXG.deprecated('strokeWidth()', 'setAttribute()');
             this.setAttribute({strokeWidth: width});
             return this;
         },
@@ -1397,9 +1470,10 @@ define([
          * Set the fillColor of an element
          * @param {String} fColor String which determines the fill color of an object.
          * @see JXG.GeometryElement#fillColor
-         * @deprecated Use {@link #setAttribute}
+         * @deprecated Use {@link JXG.GeometryElement#setAttribute}
          */
         fillColor: function (fColor) {
+            JXG.deprecated('fillColor()', 'setAttribute()');
             this.setAttribute({fillColor: fColor});
             return this;
         },
@@ -1408,9 +1482,10 @@ define([
          * Set the highlightFillColor of an element
          * @param {String} fColor String which determines the fill color of an object when its highlighted.
          * @see JXG.GeometryElement#highlightFillColor
-         * @deprecated Use {@link #setAttribute}
+         * @deprecated Use {@link JXG.GeometryElement#setAttribute}
          */
         highlightFillColor: function (fColor) {
+            JXG.deprecated('highlightFillColor()', 'setAttribute()');
             this.setAttribute({highlightFillColor: fColor});
             return this;
         },
@@ -1419,9 +1494,10 @@ define([
          * Set the labelColor of an element
          * @param {String} lColor String which determines the text color of an object's label.
          * @see JXG.GeometryElement#labelColor
-         * @deprecated Use {@link #setAttribute}
+         * @deprecated Use {@link JXG.GeometryElement#setAttribute}
          */
         labelColor: function (lColor) {
+            JXG.deprecated('labelColor()', 'setAttribute()');
             this.setAttribute({labelColor: lColor});
             return this;
         },
@@ -1430,9 +1506,10 @@ define([
          * Set the dash type of an element
          * @param {Number} d Integer which determines the way of dashing an element's outline.
          * @see JXG.GeometryElement#dash
-         * @deprecated Use {@link #setAttribute}
+         * @deprecated Use {@link JXG.GeometryElement#setAttribute}
          */
         dash: function (d) {
+            JXG.deprecated('dash()', 'setAttribute()');
             this.setAttribute({dash: d});
             return this;
         },
@@ -1441,9 +1518,10 @@ define([
          * Set the visibility of an element
          * @param {Boolean} v Boolean which determines whether the element is drawn.
          * @see JXG.GeometryElement#visible
-         * @deprecated Use {@link #setAttribute}
+         * @deprecated Use {@link JXG.GeometryElement#setAttribute}
          */
         visible: function (v) {
+            JXG.deprecated('visible()', 'setAttribute()');
             this.setAttribute({visible: v});
             return this;
         },
@@ -1452,9 +1530,10 @@ define([
          * Set the shadow of an element
          * @param {Boolean} s Boolean which determines whether the element has a shadow or not.
          * @see JXG.GeometryElement#shadow
-         * @deprecated Use {@link #setAttribute}
+         * @deprecated Use {@link JXG.GeometryElement#setAttribute}
          */
         shadow: function (s) {
+            JXG.deprecated('shadow()', 'setAttribute()');
             this.setAttribute({shadow: s});
             return this;
         },
@@ -1502,15 +1581,18 @@ define([
          */
         getAttributes: function () {
             var attributes = Type.deepCopy(this.visProp),
+                /*
                 cleanThis = ['attractors', 'snatchdistance', 'traceattributes', 'frozen',
                     'shadow', 'gradientangle', 'gradientsecondopacity', 'gradientpositionx', 'gradientpositiony',
                     'needsregularupdate', 'zoom', 'layer', 'offset'],
-                i;
+                */
+                cleanThis = [],
+                i, len = cleanThis.length;
 
             attributes.id = this.id;
             attributes.name = this.name;
 
-            for (i = 0; i < cleanThis.length; i++) {
+            for (i = 0; i < len; i++) {
                 delete attributes[cleanThis[i]];
             }
 
@@ -1532,10 +1614,16 @@ define([
          * The function uses the coords object of the element as
          * its actual position. If there is no coords object, nothing is done.
          * @param {Boolean} force force snapping independent from what the snaptogrid attribute says
+         * @param {Boolean} fromParent True if the drag comes from a child element. This is the case if a line
+         *    through two points is dragged. In this case we do not try to force the points to stay inside of
+         *    the visible board, but the distance between the two points stays constant.
          * @returns {JXG.GeometryElement} Reference to this element
          */
-        handleSnapToGrid: function (force) {
+        handleSnapToGrid: function (force, fromParent) {
             var x, y, ticks,
+                //i, len, g, el, p,
+                boardBB,
+                needsSnapToGrid = false,
                 sX = this.visProp.snapsizex,
                 sY = this.visProp.snapsizey;
 
@@ -1543,7 +1631,30 @@ define([
                 return this;
             }
 
-            if (this.visProp.snaptogrid || force === true) {
+            needsSnapToGrid = this.visProp.snaptogrid || force === true;
+
+            // Test if in any of the groups this element is member of
+            // there is an element with snaptogrid == true.
+            /*
+            if (!needsSnapToGrid && Type.exists(this.groups)) {
+                len = this.groups.length;
+                for (i = 0; i < len; ++i) {
+                    g = this.board.groups[this.groups[i]];
+                    for (el in g.objects) {
+                        if (g.objects.hasOwnProperty(el)) {
+                            if (g.objects[el].point.visProp.snaptogrid) {
+                                needsSnapToGrid = true;
+                                // Leave both loops immediately
+                                i = len;
+                                break;
+                            }
+                        }
+                    }
+                }
+            }
+            */
+
+            if (needsSnapToGrid) {
                 x = this.coords.usrCoords[1];
                 y = this.coords.usrCoords[2];
 
@@ -1559,19 +1670,46 @@ define([
 
                 // if no valid snap sizes are available, don't change the coords.
                 if (sX > 0 && sY > 0) {
-                    this.coords.setCoordinates(Const.COORDS_BY_USER, [Math.round(x / sX) * sX, Math.round(y / sY) * sY]);
+                    boardBB = this.board.getBoundingBox();
+                    x = Math.round(x / sX) * sX;
+                    y = Math.round(y / sY) * sY;
+
+                    // checking whether x and y are still within boundingBox,
+                    // if not, adjust them to remain within the board
+                    if (!fromParent) {
+                        if (x < boardBB[0]) {
+                            x += sX;
+                        } else if (x > boardBB[2]) {
+                            x -= sX;
+                        }
+
+                        if (y < boardBB[3]) {
+                            y += sY;
+                        } else if (y > boardBB[1]) {
+                            y -= sY;
+                        }
+                    }
+                    this.coords.setCoordinates(Const.COORDS_BY_USER, [x, y]);
                 }
             }
             return this;
         },
 
         /**
-         * Alias of {@link JXG.GeometryElement#on}.
+         * Alias of {@link JXG.EventEmitter.on}.
+         *
+         * @name addEvent
+         * @memberof JXG.GeometryElement
+         * @function
          */
         addEvent: JXG.shortcut(JXG.GeometryElement.prototype, 'on'),
 
         /**
-         * Alias of {@link JXG.GeometryElement#off}.
+         * Alias of {@link JXG.EventEmitter.off}.
+         *
+         * @name removeEvent
+         * @memberof JXG.GeometryElement
+         * @function
          */
         removeEvent: JXG.shortcut(JXG.GeometryElement.prototype, 'off'),
 
