@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2015
+    Copyright 2008-2016
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -217,7 +217,7 @@ define([
         },
 
         /**
-         * Set the style of a point. 
+         * Set the style of a point.
          * Used for GEONExT import and should not be used to set the point's face and size.
          * @param {Number} i Integer to determine the style.
          * @private
@@ -253,9 +253,10 @@ define([
         /**
          * @deprecated Use JXG#normalizePointFace instead
          * @param s
-         * @return {*}
+         * @returns {*}
          */
         normalizeFace: function (s) {
+            JXG.deprecated('Point.normalizeFace()', 'JXG.normalizePointFace()');
             return Options.normalizePointFace(s);
         },
 
@@ -266,6 +267,7 @@ define([
          * @deprecated Use setAttribute()
          */
         face: function (f) {
+            JXG.deprecated('Point.face()', 'Point.setAttribute()');
             this.setAttribute({face: f});
         },
 
@@ -276,6 +278,7 @@ define([
          * @deprecated Use setAttribute()
          */
         size: function (s) {
+            JXG.deprecated('Point.size()', 'Point.setAttribute()');
             this.setAttribute({size: s});
         },
 
@@ -320,12 +323,13 @@ define([
      * that means the user won't be able to change the point's position directly by mouse because it will be calculated automatically depending on the string
      * or the function's return value. If two parent elements are given the coordinates will be interpreted as 2D affine Euclidean coordinates, if three such
      * parent elements are given they will be interpreted as homogeneous coordinates.
-     * @param {JXG.Point_JXG.Transformation} Point,Transformation A point can also be created providing a transformation. The resulting point is a clone of the base
-     * point transformed by the given Transformation. {@see JXG.Transformation}.
+     * @param {JXG.Point_JXG.Transformation_Array} Point,Transformation A point can also be created providing a transformation or an array of transformations.
+     * The resulting point is a clone of the base point transformed by the given Transformation. {@see JXG.Transformation}.
+     *
      * @example
      * // Create a free point using affine euclidean coordinates
      * var p1 = board.create('point', [3.5, 2.0]);
-     * </pre><div id="672f1764-7dfa-4abc-a2c6-81fbbf83e44b" style="width: 200px; height: 200px;"></div>
+     * </pre><div class="jxgbox"id="672f1764-7dfa-4abc-a2c6-81fbbf83e44b" style="width: 200px; height: 200px;"></div>
      * <script type="text/javascript">
      *   var board = JXG.JSXGraph.initBoard('672f1764-7dfa-4abc-a2c6-81fbbf83e44b', {boundingbox: [-1, 5, 5, -1], axis: true, showcopyright: false, shownavigation: false});
      *   var p1 = board.create('point', [3.5, 2.0]);
@@ -333,7 +337,7 @@ define([
      * @example
      * // Create a constrained point using anonymous function
      * var p2 = board.create('point', [3.5, function () { return p1.X(); }]);
-     * </pre><div id="4fd4410c-3383-4e80-b1bb-961f5eeef224" style="width: 200px; height: 200px;"></div>
+     * </pre><div class="jxgbox"id="4fd4410c-3383-4e80-b1bb-961f5eeef224" style="width: 200px; height: 200px;"></div>
      * <script type="text/javascript">
      *   var fpex1_board = JXG.JSXGraph.initBoard('4fd4410c-3383-4e80-b1bb-961f5eeef224', {boundingbox: [-1, 5, 5, -1], axis: true, showcopyright: false, shownavigation: false});
      *   var fpex1_p1 = fpex1_board.create('point', [3.5, 2.0]);
@@ -343,7 +347,7 @@ define([
      * // Create a point using transformations
      * var trans = board.create('transform', [2, 0.5], {type:'scale'});
      * var p3 = board.create('point', [p2, trans]);
-     * </pre><div id="630afdf3-0a64-46e0-8a44-f51bd197bb8d" style="width: 400px; height: 400px;"></div>
+     * </pre><div class="jxgbox"id="630afdf3-0a64-46e0-8a44-f51bd197bb8d" style="width: 400px; height: 400px;"></div>
      * <script type="text/javascript">
      *   var fpex2_board = JXG.JSXGraph.initBoard('630afdf3-0a64-46e0-8a44-f51bd197bb8d', {boundingbox: [-1, 9, 9, -1], axis: true, showcopyright: false, shownavigation: false});
      *   var fpex2_trans = fpex2_board.create('transform', [2, 0.5], {type:'scale'});
@@ -383,7 +387,7 @@ define([
      * var p1 = board.create('point', [2.0, 2.0]);
      * var c1 = board.create('circle', [p1, 2.0]);
      * var p2 = board.create('glider', [2.0, 1.5, c1]);
-     * </pre><div id="4f65f32f-e50a-4b50-9b7c-f6ec41652930" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="4f65f32f-e50a-4b50-9b7c-f6ec41652930" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var gpex1_board = JXG.JSXGraph.initBoard('4f65f32f-e50a-4b50-9b7c-f6ec41652930', {boundingbox: [-1, 5, 5, -1], axis: true, showcopyright: false, shownavigation: false});
      *   var gpex1_p1 = gpex1_board.create('point', [2.0, 2.0]);
@@ -395,7 +399,7 @@ define([
      * var p1 = board.create('point', [2.0, 2.0]);
      * var c1 = board.create('circle', [p1, 2.0]);
      * var p2 = board.create('glider', [c1]);
-     * </pre><div id="4de7f181-631a-44b1-a12f-bc4d995609e8" style="width: 200px; height: 200px;"></div>
+     * </pre><div class="jxgbox"id="4de7f181-631a-44b1-a12f-bc4d995609e8" style="width: 200px; height: 200px;"></div>
      * <script type="text/javascript">
      *   var gpex2_board = JXG.JSXGraph.initBoard('4de7f181-631a-44b1-a12f-bc4d995609e8', {boundingbox: [-1, 5, 5, -1], axis: true, showcopyright: false, shownavigation: false});
      *   var gpex2_p1 = gpex2_board.create('point', [2.0, 2.0]);
@@ -445,7 +449,7 @@ define([
      * var l1 = board.create('line', [p2, p3]);
      *
      * var i = board.create('intersection', [c1, l1, 0]);
-     * </pre><div id="e5b0e190-5200-4bc3-b995-b6cc53dc5dc0" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="e5b0e190-5200-4bc3-b995-b6cc53dc5dc0" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var ipex1_board = JXG.JSXGraph.initBoard('e5b0e190-5200-4bc3-b995-b6cc53dc5dc0', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false});
      *   var ipex1_p1 = ipex1_board.create('point', [4.0, 4.0]);
@@ -484,7 +488,19 @@ define([
 
         el.type = Const.OBJECT_TYPE_INTERSECTION;
         el.elType = 'intersection';
-        el.parents = [el1.id, el2.id, i, j];
+        el.setParents([el1.id, el2.id]);
+
+        /**
+         * Array of length 2 containing the numbers i and j.
+         * The intersection point is i-th intersection point.
+         * j is unused.
+         * @type Array
+         * @private
+         */
+        el.intersectionNumbers = [i, j];
+        el.getParents = function() {
+            return this.parents.concat(this.intersectionNumbers);
+        };
 
         el.generatePolynomial = function () {
             var poly1 = el1.generatePolynomial(el),
@@ -523,7 +539,7 @@ define([
      *
      * var i = board.create('intersection', [c1, l1, 0]);
      * var j = board.create('otherintersection', [c1, l1, i]);
-     * </pre><div id="45e25f12-a1de-4257-a466-27a2ae73614c" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="45e25f12-a1de-4257-a466-27a2ae73614c" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var ipex2_board = JXG.JSXGraph.initBoard('45e25f12-a1de-4257-a466-27a2ae73614c', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false});
      *   var ipex2_p1 = ipex2_board.create('point', [4.0, 4.0]);
@@ -566,7 +582,7 @@ define([
 
         el.type = Const.OBJECT_TYPE_INTERSECTION;
         el.elType = 'otherintersection';
-        el.parents = [el1.id, el2.id, other];
+        el.setParents([el1.id, el2.id, other]);
 
         el1.addChild(el);
         el2.addChild(el);
@@ -611,7 +627,7 @@ define([
      * var p7 = board.create('point', [2, -2]);
      * var l1 = board.create('line', [p6, p7]);
      * var p8 = board.create('polepoint', [c1, l1]);
-     * </pre><div id='7b7233a0-f363-47dd-9df5-8018d0d17a98' class='jxgbox' style='width:400px; height:400px;'></div>
+     * </pre><div class="jxgbox"id='7b7233a0-f363-47dd-9df5-8018d0d17a98' class='jxgbox' style='width:400px; height:400px;'></div>
      * <script type='text/javascript'>
      * var ppex1_board = JXG.JSXGraph.initBoard('7b7233a0-f363-47dd-9df5-8018d0d17a98', {boundingbox: [-3, 5, 5, -3], axis: true, showcopyright: false, shownavigation: false});
      * var ppex1_p1 = ppex1_board.create('point', [-1, 2]);
@@ -634,7 +650,7 @@ define([
      * var p4 = board.create('point', [4, -1]);
      * var l1 = board.create('line', [p3, p4]);
      * var p5 = board.create('polepoint', [c1, l1]);
-     * </pre><div id='7b7233a0-f363-47dd-9df5-9018d0d17a98' class='jxgbox' style='width:400px; height:400px;'></div>
+     * </pre><div class="jxgbox"id='7b7233a0-f363-47dd-9df5-9018d0d17a98' class='jxgbox' style='width:400px; height:400px;'></div>
      * <script type='text/javascript'>
      * var ppex2_board = JXG.JSXGraph.initBoard('7b7233a0-f363-47dd-9df5-9018d0d17a98', {boundingbox: [-3, 7, 7, -3], axis: true, showcopyright: false, shownavigation: false});
      * var ppex2_p1 = ppex2_board.create('point', [1, 1]);
@@ -696,7 +712,7 @@ define([
             }], attributes);
 
         el.elType = 'polepoint';
-        el.parents = [el1.id, el2.id];
+        el.setParents([el1.id, el2.id]);
 
         el1.addChild(el);
         el2.addChild(el);
