@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2015
+    Copyright 2008-2016
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -46,8 +46,8 @@
  */
 
 define([
-    'jxg', 'base/constants', 'base/coords', 'math/statistics', 'utils/type', 'base/element', 'base/line', 'base/transformation'
-], function (JXG, Const, Coords, Statistics, Type, GeometryElement, Line, Transform) {
+    'jxg', 'base/constants', 'base/coords', 'math/statistics', 'math/geometry', 'utils/type', 'base/element', 'base/line', 'base/transformation'
+], function (JXG, Const, Coords, Statistics, Geometry, Type, GeometryElement, Line, Transform) {
 
     "use strict";
 
@@ -83,7 +83,8 @@ define([
             this.vertices[i] = vertex;
         }
 
-        if (this.vertices[this.vertices.length - 1] !== this.vertices[0]) {
+        // Close the polygon
+        if (this.vertices.length > 0 && this.vertices[this.vertices.length - 1].id !== this.vertices[0].id) {
             this.vertices.push(this.vertices[0]);
         }
 
@@ -126,6 +127,8 @@ define([
 
         this.board.renderer.drawPolygon(this);
         this.board.finalizeAdding(this);
+
+        this.createGradient();
         this.elType = 'polygon';
 
         // create label
@@ -137,6 +140,7 @@ define([
             A: 'Area',
             Area: 'Area',
             boundingBox: 'boundingBox',
+            bounds: 'bounds',
             addPoints: 'addPoints',
             insertPoints: 'insertPoints',
             removePoints: 'removePoints'
@@ -150,7 +154,7 @@ define([
          * Checks whether (x,y) is near the polygon.
          * @param {Number} x Coordinate in x direction, screen coordinates.
          * @param {Number} y Coordinate in y direction, screen coordinates.
-         * @return {Boolean} Returns true, if (x,y) is inside or at the boundary the polygon, otherwise false.
+         * @returns {Boolean} Returns true, if (x,y) is inside or at the boundary the polygon, otherwise false.
          */
         hasPoint: function (x, y) {
 
@@ -202,12 +206,16 @@ define([
          * return TextAnchor
          */
         getTextAnchor: function () {
-            var a = this.vertices[0].X(),
-                b = this.vertices[0].Y(),
-                x = a,
-                y = b,
-                i;
+            var a, b, x, y, i;
 
+            if (this.vertices.length === 0) {
+                return new Coords(Const.COORDS_BY_USER, [1, 0, 0], this.board);
+            }
+
+            a = this.vertices[0].X();
+            b = this.vertices[0].Y();
+            x = a;
+            y = b;
             for (i = 0; i < this.vertices.length; i++) {
                 if (this.vertices[i].X() < a) {
                     a = this.vertices[i].X();
@@ -308,28 +316,19 @@ define([
          * @returns {Number} Area of (not self-intersecting) polygon
          */
         Area: function () {
-            //Surveyor's Formula
-            var i,
-                area = 0;
-
-            for (i = 0; i < this.vertices.length - 1; i++) {
-                area += (this.vertices[i].X() * this.vertices[i + 1].Y() - this.vertices[i + 1].X() * this.vertices[i].Y());
-            }
-            area /= 2.0;
-
-            return Math.abs(area);
+            return Math.abs(Geometry.signedPolygon(this.vertices, true));
         },
 
         /**
          * Bounding box of a polygon. The bounding box is an array of four numbers: the first two numbers
          * determine the upper left corner, the last two number determine the lower right corner of the bounding box.
-         * 
+         *
          * The width and height of a polygon can then determined like this:
          * @example
          * var box = polygon.boundingBox();
          * var width = box[2] - box[0];
          * var height = box[1] - box[3];
-         * 
+         *
          * @returns {Array} Array containing four numbers: [minX, maxY, maxX, minY]
          */
         boundingBox: function () {
@@ -363,6 +362,11 @@ define([
             return box;
         },
 
+        // already documented in GeometryElement
+        bounds: function () {
+            return this.boundingBox();
+        },
+
         /**
          * This method removes the SVG or VML nodes of the lines and the filled area from the renderer, to remove
          * the object completely you should use {@link JXG.Board#removeObject}.
@@ -564,13 +568,10 @@ define([
             return this;
         },
 
+        // documented in element.js
         getParents: function () {
-            var p = [], i;
-
-            for (i = 0; i < this.vertices.length; i++) {
-                p.push(this.vertices[i].id);
-            }
-            return p;
+            this.setParents(this.vertices);
+            return this.parents;
         },
 
         getAttributes: function () {
@@ -622,15 +623,190 @@ define([
             t.applyOnce(this.vertices.slice(0, -1));
 
             return this;
+        },
+
+        /**
+        * Algorithm by Sutherland and Hodgman to compute the intersection of two convex polygons.
+        * The polygon itself is the clipping polygon, it expects as parameter a polygon to be clipped.
+        * See <a href="https://en.wikipedia.org/wiki/Sutherland%E2%80%93Hodgman_algorithm">wikipedia entry</a>.
+        * Called by {@link JXG.Polygon#intersect}.
+        *
+        * @private
+        *
+        * @param {JXG.Polygon} polygon Polygon which will be clipped.
+        *
+        * @returns {Array} of (normalized homogeneous user) coordinates (i.e. [z, x, y], where z==1 in most cases,
+        *   representing the vertices of the intersection polygon.
+        *
+        */
+        sutherlandHodgman: function(polygon) {
+            // First the two polygons are sorted counter clockwise
+            var clip = JXG.Math.Geometry.sortVertices(this.vertices),   // "this" is the clipping polygon
+                subject = JXG.Math.Geometry.sortVertices(polygon.vertices), // "polygon" is the subject polygon
+
+                lenClip = clip.length - 1,
+                lenSubject = subject.length - 1,
+                lenIn,
+
+                outputList = [],
+                inputList, i, j, S, E, cross,
+
+
+                // Determines if the point c3 is right of the line through c1 and c2.
+                // Since the polygons are sorted counter clockwise, "right of" and therefore >= is needed here
+                isInside = function(c1, c2, c3) {
+                    return ((c2[1] - c1[1]) * (c3[2] - c1[2]) - (c2[2] - c1[2]) * (c3[1] - c1[1])) >= 0;
+                };
+
+            for (i = 0; i < lenSubject; i++) {
+                outputList.push(subject[i]);
+            }
+
+            for (i = 0; i < lenClip; i++) {
+                inputList = outputList.slice(0);
+                lenIn = inputList.length;
+                outputList = [];
+
+                S = inputList[lenIn - 1];
+
+                for (j = 0; j < lenIn; j++) {
+                    E = inputList[j];
+                    if (isInside(clip[i], clip[i + 1], E)) {
+                        if (!isInside(clip[i], clip[i + 1], S)) {
+                            cross = JXG.Math.Geometry.meetSegmentSegment(S, E, clip[i], clip[i + 1]);
+                            cross[0][1] /= cross[0][0];
+                            cross[0][2] /= cross[0][0];
+                            cross[0][0] = 1;
+                            outputList.push(cross[0]);
+                        }
+                        outputList.push(E);
+                    } else if (isInside(clip[i], clip[i + 1], S)) {
+                        cross = JXG.Math.Geometry.meetSegmentSegment(S, E, clip[i], clip[i + 1]);
+                        cross[0][1] /= cross[0][0];
+                        cross[0][2] /= cross[0][0];
+                        cross[0][0] = 1;
+                        outputList.push(cross[0]);
+                    }
+                    S = E;
+                }
+            }
+
+            return outputList;
+        },
+
+        /**
+         * Generic method for the intersection of this polygon with another polygon.
+         * The parent object is the clipping polygon, it expects as parameter a polygon to be clipped.
+         * Both polygons have to be convex.
+         * Calls {@link JXG.Polygon#sutherlandHodgman}.
+         *
+         * @param {JXG.Polygon} polygon Polygon which will be clipped.
+         *
+         * @returns {Array} of (normalized homogeneous user) coordinates (i.e. [z, x, y], where z==1 in most cases,
+         *   representing the vertices of the intersection polygon.
+         *
+         * @example
+         *  // Static intersection of two polygons pol1 and pol2
+         *  var pol1 = board.create('polygon', [[-2, 3], [-4, -3], [2, 0], [4, 4]], {
+         *                name:'pol1', withLabel: true,
+         *                fillColor: 'yellow'
+         *             });
+         *  var pol2 = board.create('polygon', [[-2, -3], [-4, 1], [0, 4], [5, 1]], {
+         *                name:'pol2', withLabel: true
+         *             });
+         *
+         *  // Static version:
+         *  // the intersection polygon does not adapt to changes of pol1 or pol2.
+         *  var pol3 = board.create('polygon', pol1.intersect(pol2), {fillColor: 'blue'});
+         * </pre><div class="jxgbox"id="d1fe5ea9-309f-494a-af07-ee3d033acb7c" style="width: 300px; height: 300px;"></div>
+         * <script type="text/javascript">
+         *   (function() {
+         *       var board = JXG.JSXGraph.initBoard('d1fe5ea9-309f-494a-af07-ee3d033acb7c', {boundingbox: [-8, 8, 8,-8], axis: true, showcopyright: false, shownavigation: false});
+         *       // Intersect two polygons pol1 and pol2
+         *       var pol1 = board.create('polygon', [[-2, 3], [-4, -3], [2, 0], [4, 4]], {
+         *                name:'pol1', withLabel: true,
+         *                fillColor: 'yellow'
+         *             });
+         *       var pol2 = board.create('polygon', [[-2, -3], [-4, 1], [0, 4], [5, 1]], {
+         *                name:'pol2', withLabel: true
+         *             });
+         *
+         *       // Static version: the intersection polygon does not adapt to changes of pol1 or pol2.
+         *       var pol3 = board.create('polygon', pol1.intersect(pol2), {fillColor: 'blue'});
+         *   })();
+         * </script><pre>
+         *
+         * @example
+         *  // Dynamic intersection of two polygons pol1 and pol2
+         *  var pol1 = board.create('polygon', [[-2, 3], [-4, -3], [2, 0], [4, 4]], {
+         *                name:'pol1', withLabel: true,
+         *                fillColor: 'yellow'
+         *             });
+         *  var pol2 = board.create('polygon', [[-2, -3], [-4, 1], [0, 4], [5, 1]], {
+         *                name:'pol2', withLabel: true
+         *             });
+         *
+         *  // Dynamic version:
+         *  // the intersection polygon does  adapt to changes of pol1 or pol2.
+         *  // For this a curve element is used.
+         *  var curve = board.create('curve', [[],[]], {fillColor: 'blue', fillOpacity: 0.4});
+         *  curve.updateDataArray = function() {
+         *      var mat = JXG.Math.transpose(pol1.intersect(pol2));
+         *
+         *      if (mat.length == 3) {
+         *          this.dataX = mat[1];
+         *          this.dataY = mat[2];
+         *      } else {
+         *          this.dataX = [];
+         *          this.dataY = [];
+         *      }
+         *  };
+         *  board.update();
+         * </pre><div class="jxgbox"id="f870d516-ca1a-4140-8fe3-5d64fb42e5f2" style="width: 300px; height: 300px;"></div>
+         * <script type="text/javascript">
+         *   (function() {
+         *       var board = JXG.JSXGraph.initBoard('f870d516-ca1a-4140-8fe3-5d64fb42e5f2', {boundingbox: [-8, 8, 8,-8], axis: true, showcopyright: false, shownavigation: false});
+         *       // Intersect two polygons pol1 and pol2
+         *       var pol1 = board.create('polygon', [[-2, 3], [-4, -3], [2, 0], [4, 4]], {
+         *                name:'pol1', withLabel: true,
+         *                fillColor: 'yellow'
+         *             });
+         *       var pol2 = board.create('polygon', [[-2, -3], [-4, 1], [0, 4], [5, 1]], {
+         *                name:'pol2', withLabel: true
+         *             });
+         *
+         *  // Dynamic version:
+         *  // the intersection polygon does  adapt to changes of pol1 or pol2.
+         *  // For this a curve element is used.
+         *    var curve = board.create('curve', [[],[]], {fillColor: 'blue', fillOpacity: 0.4});
+         *    curve.updateDataArray = function() {
+         *        var mat = JXG.Math.transpose(pol1.intersect(pol2));
+         *
+         *        if (mat.length == 3) {
+         *            this.dataX = mat[1];
+         *            this.dataY = mat[2];
+         *        } else {
+         *            this.dataX = [];
+         *            this.dataY = [];
+         *        }
+         *    };
+         *    board.update();
+         *   })();
+         * </script><pre>
+         *
+         */
+        intersect: function(polygon) {
+            return this.sutherlandHodgman(polygon);
         }
 
+
     });
 
 
     /**
-     * @class A polygon is an area enclosed by a set of border lines which are determined by 
+     * @class A polygon is an area enclosed by a set of border lines which are determined by
      * <ul>
-     *    <li> a list of points or 
+     *    <li> a list of points or
      *    <li> a list of coordinate arrays or
      *    <li> a function returning a list of coordinate arrays.
      * </ul>
@@ -650,7 +826,7 @@ define([
      * var p4 = board.create('point', [1.0, 4.0]);
      *
      * var pol = board.create('polygon', [p1, p2, p3, p4]);
-     * </pre><div id="682069e9-9e2c-4f63-9b73-e26f8a2b2bb1" style="width: 400px; height: 400px;"></div>
+     * </pre><div class="jxgbox"id="682069e9-9e2c-4f63-9b73-e26f8a2b2bb1" style="width: 400px; height: 400px;"></div>
      * <script type="text/javascript">
      *  (function () {
      *   var board = JXG.JSXGraph.initBoard('682069e9-9e2c-4f63-9b73-e26f8a2b2bb1', {boundingbox: [-1, 9, 9, -1], axis: false, showcopyright: false, shownavigation: false}),
@@ -666,7 +842,7 @@ define([
      * var p = [[0.0, 2.0], [2.0, 1.0], [4.0, 6.0], [4.0, 6.0], [4.0, 6.0], [1.0, 3.0]];
      *
      * var pol = board.create('polygon', p, {hasInnerPoints: true});
-     * </pre><div id="9f9a5946-112a-4768-99ca-f30792bcdefb" style="width: 400px; height: 400px;"></div>
+     * </pre><div class="jxgbox"id="9f9a5946-112a-4768-99ca-f30792bcdefb" style="width: 400px; height: 400px;"></div>
      * <script type="text/javascript">
      *  (function () {
      *   var board = JXG.JSXGraph.initBoard('9f9a5946-112a-4768-99ca-f30792bcdefb', {boundingbox: [-1, 9, 9, -1], axis: false, showcopyright: false, shownavigation: false}),
@@ -676,20 +852,20 @@ define([
      * </script><pre>
      *
      * @example
-     *   var f1 = function() { return [0.0, 2.0]; }, 
-     *       f2 = function() { return [2.0, 1.0]; }, 
-     *       f3 = function() { return [4.0, 6.0]; }, 
-     *       f4 = function() { return [1.0, 4.0]; }, 
+     *   var f1 = function() { return [0.0, 2.0]; },
+     *       f2 = function() { return [2.0, 1.0]; },
+     *       f3 = function() { return [4.0, 6.0]; },
+     *       f4 = function() { return [1.0, 4.0]; },
      *       cc1 = board.create('polygon', [f1, f2, f3, f4]);
      *
-     * </pre><div id="ceb09915-b783-44db-adff-7877ae3534c8" style="width: 400px; height: 400px;"></div>
+     * </pre><div class="jxgbox"id="ceb09915-b783-44db-adff-7877ae3534c8" style="width: 400px; height: 400px;"></div>
      * <script type="text/javascript">
      *  (function () {
      *   var board = JXG.JSXGraph.initBoard('ceb09915-b783-44db-adff-7877ae3534c8', {boundingbox: [-1, 9, 9, -1], axis: false, showcopyright: false, shownavigation: false}),
-     *       f1 = function() { return [0.0, 2.0]; }, 
-     *       f2 = function() { return [2.0, 1.0]; }, 
-     *       f3 = function() { return [4.0, 6.0]; }, 
-     *       f4 = function() { return [1.0, 4.0]; }, 
+     *       f1 = function() { return [0.0, 2.0]; },
+     *       f2 = function() { return [2.0, 1.0]; },
+     *       f3 = function() { return [4.0, 6.0]; },
+     *       f4 = function() { return [1.0, 4.0]; },
      *       cc1 = board.create('polygon', [f1, f2, f3, f4]);
      *  })();
      * </script><pre>
@@ -726,7 +902,7 @@ define([
      * var p2 = board.create('point', [2.0, 1.0]);
      *
      * var pol = board.create('regularpolygon', [p1, p2, 5]);
-     * </pre><div id="682069e9-9e2c-4f63-9b73-e26f8a2b2bb1" style="width: 400px; height: 400px;"></div>
+     * </pre><div class="jxgbox"id="682069e9-9e2c-4f63-9b73-e26f8a2b2bb1" style="width: 400px; height: 400px;"></div>
      * <script type="text/javascript">
      *  (function () {
      *   var board = JXG.JSXGraph.initBoard('682069e9-9e2c-4f63-9b73-e26f8a2b2bb1', {boundingbox: [-1, 9, 9, -1], axis: false, showcopyright: false, shownavigation: false}),
@@ -741,7 +917,7 @@ define([
      * var p3 = board.create('point', [2.0,0.0]);
      *
      * var pol = board.create('regularpolygon', [p1, p2, p3]);
-     * </pre><div id="096a78b3-bd50-4bac-b958-3be5e7df17ed" style="width: 400px; height: 400px;"></div>
+     * </pre><div class="jxgbox"id="096a78b3-bd50-4bac-b958-3be5e7df17ed" style="width: 400px; height: 400px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('096a78b3-bd50-4bac-b958-3be5e7df17ed', {boundingbox: [-1, 9, 9, -1], axis: false, showcopyright: false, shownavigation: false}),
