@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2015
+    Copyright 2008-2016
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -65,10 +65,10 @@ define([
 
     /**
      * Construct and handle texts.
-     * 
-     * The coordinates can be relative to the coordinates of an element 
+     *
+     * The coordinates can be relative to the coordinates of an element
      * given in {@link JXG.Options#text.anchor}.
-     * 
+     *
      * MathJax, HTML and GEONExT syntax can be handled.
      * @class Creates a new text object. Do not use this constructor to create a text. Use {@link JXG.Board#create} with
      * type {@link Text} instead.
@@ -104,7 +104,7 @@ define([
         this.board.renderer.drawText(this);
         this.board.finalizeAdding(this);
 
-        if (typeof this.content === 'string') {
+        if (Type.isString(this.content)) {
             this.notifyParents(this.content);
         }
         this.elType = 'text';
@@ -125,21 +125,19 @@ define([
          * Test if the the screen coordinates (x,y) are in a small stripe
          * at the left side or at the right side of the text.
          * Sensitivity is set in this.board.options.precision.hasPoint.
-         * If dragarea is set to 'all' (default), tests if the the screen 
+         * If dragarea is set to 'all' (default), tests if the the screen
         * coordinates (x,y) are in within the text boundary.
          * @param {Number} x
          * @param {Number} y
-         * @return {Boolean}
+         * @returns {Boolean}
          */
         hasPoint: function (x, y) {
             var lft, rt, top, bot,
                 r = this.board.options.precision.hasPoint;
 
             if (this.transformations.length > 0) {
-                /**
-                 * Transform the mouse/touch coordinates
-                 * back to the original position of the text.
-                 */
+                //Transform the mouse/touch coordinates
+                // back to the original position of the text.
                 lft = Mat.matVecMult(Mat.inverse(this.board.renderer.joinTransforms(this, this.transformations)), [1, x, y]);
                 x = lft[1];
                 y = lft[2];
@@ -182,7 +180,7 @@ define([
             var updateText;
 
             this.orgText = text;
-            if (typeof text === 'function') {
+            if (Type.isFunction(text)) {
                 this.updateText = function () {
                     if (this.visProp.parse && !this.visProp.usemathjax) {
                         this.plaintext = this.replaceSub(this.replaceSup(this.convertGeonext2CSS(text())));
@@ -205,7 +203,8 @@ define([
                         this.content = "'" + text + "'";
                     } else {
                         // Converts GEONExT syntax into JavaScript string
-                        this.content = this.generateTerm(text);
+                        // Short math is allowed
+                        this.content = this.generateTerm(text, true);
                     }
                 }
                 updateText = this.board.jc.snippet(this.content, true, '', false);
@@ -219,7 +218,7 @@ define([
          * Defines new content. This is used by {@link JXG.Text#setTextJessieCode} and {@link JXG.Text#setText}. This is required because
          * JessieCode needs to filter all Texts inserted into the DOM and thus has to replace setText by setTextJessieCode.
          * @param {String|Function|Number} text
-         * @return {JXG.Text}
+         * @returns {JXG.Text}
          * @private
          */
         _setText: function (text) {
@@ -247,7 +246,7 @@ define([
 
             this.visProp.castext = text;
 
-            if (typeof text === 'function') {
+            if (Type.isFunction(text)) {
                 s = function () {
                     return Type.sanitizeHTML(text());
                 };
@@ -265,7 +264,7 @@ define([
         /**
          * Defines new content.
          * @param {String|function} text
-         * @return {JXG.Text} Reference to the text object.
+         * @returns {JXG.Text} Reference to the text object.
          */
         setText: function (text) {
             return this._setText(text);
@@ -282,22 +281,24 @@ define([
          * for aligning text.
          */
         updateSize: function () {
-            var tmp, s, that;
+            var tmp, s, that, node;
 
             if (!Env.isBrowser || this.board.renderer.type === 'no') {
                 return this;
             }
 
+            node = this.rendNode;
+
             /**
              * offsetWidth and offsetHeight seem to be supported for internal vml elements by IE10+ in IE8 mode.
              */
             if (this.visProp.display === 'html' || this.board.renderer.type === 'vml') {
-                if (JXG.exists(this.rendNode.offsetWidth)) {
-                    s = [this.rendNode.offsetWidth, this.rendNode.offsetHeight];
+                if (JXG.exists(node.offsetWidth)) {
+                    s = [node.offsetWidth, node.offsetHeight];
                     if (s[0] === 0 && s[1] === 0) { // Some browsers need some time to set offsetWidth and offsetHeight
                         that = this;
                         window.setTimeout(function () {
-                            that.size = [that.rendNode.offsetWidth, that.rendNode.offsetHeight];
+                            that.size = [node.offsetWidth, node.offsetHeight];
                         }, 0);
                     } else {
                         this.size = s;
@@ -308,7 +309,7 @@ define([
             } else if (this.visProp.display === 'internal') {
                 if (this.board.renderer.type === 'svg') {
                     try {
-                        tmp = this.rendNode.getBBox();
+                        tmp = node.getBBox();
                         this.size = [tmp.width, tmp.height];
                     } catch (e) {}
                 } else if (this.board.renderer.type === 'canvas') {
@@ -321,7 +322,7 @@ define([
 
         /**
          * A very crude estimation of the dimensions of the textbox in case nothing else is available.
-         * @return {Array}
+         * @returns {Array}
          */
         crudeSizeEstimate: function () {
             return [parseFloat(this.visProp.fontsize) * this.plaintext.length * 0.45, parseFloat(this.visProp.fontsize) * 0.9];
@@ -410,7 +411,7 @@ define([
 
         /**
          * Return the width of the text element.
-         * @return {Array} [width, height] in pixel
+         * @returns {Array} [width, height] in pixel
          */
         getSize: function () {
             return this.size;
@@ -420,7 +421,7 @@ define([
          * Move the text to new coordinates.
          * @param {number} x
          * @param {number} y
-         * @return {object} reference to the text object.
+         * @returns {object} reference to the text object.
          */
         setCoords: function (x, y) {
             var coordsAnchor, dx, dy;
@@ -514,14 +515,30 @@ define([
             return this.updateRendererGeneric('updateText');
         },
 
+        /**
+         * Converts shortened math syntax into correct syntax:  3x instead of 3*x or
+         * (a+b)(3+1) instead of (a+b)*(3+1).
+         *
+         * @private
+         * @param{String} expr Math term
+         * @returns {string} expanded String
+         */
+        expandShortMath: function(expr) {
+            var re = /([\)0-9\.])\s*([\(a-zA-Z_])/g;
+            return expr.replace(re, '$1*$2');
+        },
+
         /**
          * Converts the GEONExT syntax of the <value> terms into JavaScript.
          * Also, all Objects whose name appears in the term are searched and
          * the text is added as child to these objects.
+         *
+         * @param{String} contentStr String to be parsed
+         * @param{Boolean} [expand] Optional flag if shortened math syntax is allowed (e.g. 3x instead of 3*x).
          * @private
          * @see JXG.GeonextParser.geonext2JS.
          */
-        generateTerm: function (contentStr) {
+        generateTerm: function (contentStr, expand) {
             var res, term, i, j,
                 plaintext = '""';
 
@@ -547,6 +564,10 @@ define([
                 while (i >= 0) {
                     plaintext += ' + "' + this.replaceSub(this.replaceSup(contentStr.slice(0, i))) + '"';
                     term = contentStr.slice(i + 7, j);
+                    term = term.replace(/\s+/g, ''); // Remove all whitespace
+                    if (expand === true) {
+                        term = this.expandShortMath(term);
+                    }
                     res = GeonextParser.geonext2JS(term, this.board);
                     res = res.replace(/\\"/g, "'");
                     res = res.replace(/\\'/g, "'");
@@ -587,7 +608,7 @@ define([
          * @see JXG.Text.generateTerm @see JXG.Text._setText
          */
         convertGeonext2CSS: function (s) {
-            if (typeof s === 'string') {
+            if (Type.isString(s)) {
                 s = s.replace(/<overline>/g, '<span style=text-decoration:overline>');
                 s = s.replace(/&lt;overline&gt;/g, '<span style=text-decoration:overline>');
                 s = s.replace(/<\/overline>/g, '</span>');
@@ -629,19 +650,39 @@ define([
             return this;
         },
 
+        // documented in element.js
+        getParents: function () {
+            var p;
+            if (this.relativeCoords !== undefined) { // Texts with anchor elements, excluding labels
+                p = [this.relativeCoords.usrCoords[1], this.relativeCoords.usrCoords[2], this.orgText];
+            } else {                                 // Other texts
+                p = [this.Z(), this.X(), this.Y(), this.orgText];
+            }
+
+            if (this.parents.length !== 0) {
+                p = this.parents;
+            }
+
+            return p;
+        },
+
         bounds: function () {
             var c = this.coords.usrCoords;
 
-            return this.visProp.islabel ? [0, 0, 0, 0] : [c[1], c[2] + this.size[1], c[1] + this.size[0], c[2]];
+            if (this.visProp.islabel || this.board.unitY === 0 || this.board.unitX === 0) {
+                return [0, 0, 0, 0];
+            } else {
+                return [c[1], c[2] + this.size[1] / this.board.unitY, c[1] + this.size[0] / this.board.unitX, c[2]];
+            }
         }
     });
 
     /**
      * @class Construct and handle texts.
-     * 
-     * The coordinates can be relative to the coordinates of an element 
+     *
+     * The coordinates can be relative to the coordinates of an element
      * given in {@link JXG.Options#text.anchor}.
-     * 
+     *
      * MathJaX, HTML and GEONExT syntax can be handled.
      * @pseudo
      * @description
@@ -667,7 +708,7 @@ define([
      * @example
      * // Create a fixed text at position [0,1].
      *   var t1 = board.create('text',[0,1,"Hello World"]);
-     * </pre><div id="896013aa-f24e-4e83-ad50-7bc7df23f6b7" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="896013aa-f24e-4e83-ad50-7bc7df23f6b7" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var t1_board = JXG.JSXGraph.initBoard('896013aa-f24e-4e83-ad50-7bc7df23f6b7', {boundingbox: [-3, 6, 5, -3], axis: true, showcopyright: false, shownavigation: false});
      *   var t1 = t1_board.create('text',[0,1,"Hello World"]);
@@ -680,12 +721,29 @@ define([
      *                         function(){return "The value of s is"+s.Value().toFixed(2);}
      *                        ]
      *                     );
-     * </pre><div id="5441da79-a48d-48e8-9e53-75594c384a1c" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="5441da79-a48d-48e8-9e53-75594c384a1c" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var t2_board = JXG.JSXGraph.initBoard('5441da79-a48d-48e8-9e53-75594c384a1c', {boundingbox: [-3, 6, 5, -3], axis: true, showcopyright: false, shownavigation: false});
      *   var s = t2_board.create('slider',[[0,4],[3,4],[-2,0,2]]);
      *   var t2 = t2_board.create('text',[function(x){ return s.Value();}, 1, function(){return "The value of s is "+s.Value().toFixed(2);}]);
      * </script><pre>
+     * @example
+     * // Create a text bound to the point A
+     * var p = board.create('point',[0, 1]),
+     *     t = board.create('text',[0, -1,"Hello World"], {anchor: p});
+     *
+     * </pre><div class="jxgbox"id="ff5a64b2-2b9a-11e5-8dd9-901b0e1b8723" style="width: 300px; height: 300px;"></div>
+     * <script type="text/javascript">
+     *     (function() {
+     *         var board = JXG.JSXGraph.initBoard('ff5a64b2-2b9a-11e5-8dd9-901b0e1b8723',
+     *             {boundingbox: [-8, 8, 8,-8], axis: true, showcopyright: false, shownavigation: false});
+     *     var p = board.create('point',[0, 1]),
+     *         t = board.create('text',[0, -1,"Hello World"], {anchor: p});
+     *
+     *     })();
+     *
+     * </script><pre>
+     *
      */
     JXG.createText = function (board, parents, attributes) {
         var t,
