@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2015
+    Copyright 2008-2016
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -105,7 +105,9 @@ define([
         if (Type.isFunction(ticks)) {
             this.ticksFunction = ticks;
             throw new Error("Function arguments are no longer supported.");
-        } else if (Type.isArray(ticks)) {
+        }
+
+        if (Type.isArray(ticks)) {
             this.fixedTicks = ticks;
         } else {
             if (Math.abs(ticks) < Mat.eps || ticks < 0) {
@@ -116,22 +118,7 @@ define([
              * Ticks function:
              * determines the distance (in user units) of two major ticks
              */
-            this.ticksFunction = function () {
-                var delta, b, dist;
-
-                if (this.visProp.insertticks) {
-                    b = this.getLowerAndUpperBounds(this.getZeroCoordinates(), 'ticksdistance');
-                    dist = b.upper - b.lower;
-                    delta = Math.pow(10, Math.floor(Math.log(0.6 * dist) / Math.LN10));
-                    if (dist <= 6 * delta) {
-                        delta *= 0.5;
-                    }
-                    return delta;
-                } else {
-                    // upto 0.99.1
-                    return ticks;
-                }
-            };
+            this.ticksFunction = this.makeTicksFunction(ticks);
 
             this.equidistant = true;
         }
@@ -175,17 +162,47 @@ define([
         this.labelCounter = 0;
 
         this.id = this.line.addTicks(this);
+        this.elType = 'ticks';
         this.board.setId(this, 'Ti');
     };
 
     JXG.Ticks.prototype = new GeometryElement();
 
     JXG.extend(JXG.Ticks.prototype, /** @lends JXG.Ticks.prototype */ {
+
+        /**
+         * Ticks function:
+         * determines the distance (in user units) of two major ticks.
+         * See above in constructor and in @see JXG.GeometryElement#setAttribute
+         *
+         * @private
+         * @param {Number} ticks Distance between two major ticks
+         * @returns {Function} returns method ticksFunction
+         */
+        makeTicksFunction: function (ticks) {
+            return function () {
+                var delta, b, dist;
+
+                if (this.visProp.insertticks) {
+                    b = this.getLowerAndUpperBounds(this.getZeroCoordinates(), 'ticksdistance');
+                    dist = b.upper - b.lower;
+                    delta = Math.pow(10, Math.floor(Math.log(0.6 * dist) / Math.LN10));
+                    if (dist <= 6 * delta) {
+                        delta *= 0.5;
+                    }
+                    return delta;
+                }
+
+                // upto 0.99.1:
+                return ticks;
+            };
+        },
+
         /**
          * Checks whether (x,y) is near the line.
          * @param {Number} x Coordinate in x direction, screen coordinates.
          * @param {Number} y Coordinate in y direction, screen coordinates.
-         * @return {Boolean} True if (x,y) is near the line, False otherwise.
+         * @returns {Boolean} True if (x,y) is near the line, False otherwise.
          */
         hasPoint: function (x, y) {
             var i, t,
@@ -237,7 +254,7 @@ define([
          * @returns {JXG.Ticks} this element
          */
         setPositionDirectly: function (method, coords, oldcoords) {
-            var dx, dy, i,
+            var dx, dy,
                 c = new Coords(method, coords, this.board),
                 oldc = new Coords(method, oldcoords, this.board),
                 bb = this.board.getBoundingBox();
@@ -351,7 +368,7 @@ define([
          *
          * Otherwise, the coordinates of the point that acts as zero are established depending on the value of {@link JXG.Ticks#anchor}
          *
-         * @return {JXG.Coords} Coords object for the Zero point on the line
+         * @returns {JXG.Coords} Coords object for the Zero point on the line
          * @private
          */
         getZeroCoordinates: function () {
@@ -382,11 +399,11 @@ define([
          * If {@link JXG.Ticks#includeBoundaries} is false, the boundaries will exclude point1 and point2
          *
          * @param  {JXG.Coords} coordsZero
-         * @return {String} type  (Optional) If type=='ticksdistance' the bounds are the intersection of the line with the bounding box of the board.
-         *              Otherwise it is the projection of the corners of the bounding box to the line. The first case i s needed to automatically 
+         * @returns {String} type  (Optional) If type=='ticksdistance' the bounds are the intersection of the line with the bounding box of the board.
+         *              Otherwise it is the projection of the corners of the bounding box to the line. The first case i s needed to automatically
          *              generate ticks. The second case is for drawing of the ticks.
-         * @return {Object}     contains the lower and upper bounds
-         *                     
+         * @returns {Object}     contains the lower and upper bounds
+         *
          * @private
          */
         getLowerAndUpperBounds: function (coordsZero, type) {
@@ -408,7 +425,7 @@ define([
             if (JXG.exists(type) || type === 'tickdistance') {
                 // The good old calcStraight is needed for determining the distance between major ticks.
                 // Here, only the visual area is of importance
-                Geometry.calcStraight(this.line, point1, point2);
+                Geometry.calcStraight(this.line, point1, point2, this.line.visProp.margin);
             } else {
                 // This function projects the corners of the board to the line.
                 // This is important for diagonal lines with infinite tick lines.
@@ -456,18 +473,20 @@ define([
          *
          * @param  {JXG.Coords} zero  coordinates of the point considered zero
          * @param  {JXG.Coords} point coordinates of the point to find out the distance
-         * @return {Number}           distance between zero and point, including its sign
+         * @returns {Number}           distance between zero and point, including its sign
          * @private
          */
         getDistanceFromZero: function (zero, point) {
-            var eps = Mat.eps * Mat.eps,
+            var eps = Mat.eps,
                 distance = zero.distance(Const.COORDS_BY_USER, point);
 
             // Establish sign
             if (this.line.type === Const.OBJECT_TYPE_AXIS) {
-                if (zero.usrCoords[1] - point.usrCoords[1] > eps ||
-                        (Math.abs(zero.usrCoords[1] - point.usrCoords[1]) < eps &&
+                if ((Mat.relDif(zero.usrCoords[1], point.usrCoords[1]) > eps &&
+                        zero.usrCoords[1] - point.usrCoords[1] > eps) ||
+                    (Mat.relDif(zero.usrCoords[2], point.usrCoords[2]) > eps &&
                         zero.usrCoords[2] - point.usrCoords[2] > eps)) {
+
                     distance *= -1;
                 }
             } else if (this.visProp.anchor === 'right') {
@@ -492,10 +511,6 @@ define([
          */
         generateEquidistantTicks: function (coordsZero, bounds) {
             var tickPosition,
-                // Point 1 of the line
-                p1 = this.line.point1,
-                // Point 2 of the line
-                p2 = this.line.point2,
                 // Calculate X and Y distance between two major ticks
                 deltas = this.getXandYdeltas(),
                 // Distance between two major ticks in user coordinates
@@ -511,11 +526,16 @@ define([
             }
             this.ticksDelta = ticksDelta;
 
+            if (ticksDelta < Mat.eps) {
+                return;
+            }
+
             // Position ticks from zero to the positive side while not reaching the upper boundary
             tickPosition = 0;
             if (!this.visProp.drawzero) {
                 tickPosition = ticksDelta;
             }
+
             while (tickPosition <= bounds.upper) {
                 // Only draw ticks when we are within bounds, ignore case where  tickPosition < lower < upper
                 if (tickPosition >= bounds.lower) {
@@ -547,14 +567,13 @@ define([
          */
         adjustTickDistance: function (ticksDelta, coordsZero, deltas) {
             var nx, ny, bounds,
-                distScr, dist,
+                distScr,
                 sgn = 1;
 
             bounds = this.getLowerAndUpperBounds(coordsZero, 'ticksdistance');
             nx = coordsZero.usrCoords[1] + deltas.x * ticksDelta;
             ny = coordsZero.usrCoords[2] + deltas.y * ticksDelta;
             distScr = coordsZero.distance(Const.COORDS_BY_SCREEN, new Coords(Const.COORDS_BY_USER, [nx, ny], this.board));
-            dist = bounds.upper - bounds.lower;
             while (distScr / (this.visProp.minorticks + 1) < this.minTicksDistance) {
                 if (sgn === 1) {
                     ticksDelta *= 2;
@@ -647,7 +666,7 @@ define([
         /**
          * Calculates the x and y distance in pixel between two units in user space.
          *
-         * @return {Object}
+         * @returns {Object}
          * @private
          */
         getXandYdeltas: function () {
@@ -684,20 +703,19 @@ define([
         /**
          * @param {JXG.Coords} coords Coordinates of the tick on the line.
          * @param {Boolean} major True if tick is major tick.
-         * @return {Array} Array of length 3 containing start and end coordinates in screen coordinates
+         * @returns {Array} Array of length 3 containing start and end coordinates in screen coordinates
          *                 of the tick (arrays of length 2). 3rd entry is true if major tick otherwise false.
          *                 If the tick is outside of the canvas, the return array is empty.
          * @private
          */
         tickEndings: function (coords, major) {
-            var i, c, lineStdForm, intersection,
+            var c, lineStdForm, intersection,
                 dxs, dys,
-                s, style,
+                style,
                 cw = this.board.canvasWidth,
                 ch = this.board.canvasHeight,
                 x = [-1000 * cw, -1000 * ch],
                 y = [-1000 * cw, -1000 * ch],
-                count = 0,
                 isInsideCanvas = false;
 
             c = coords.scrCoords;
@@ -746,7 +764,7 @@ define([
          * @param  {JXG.Coords}    tick  The Coords-object of the tick to create a label for
          * @param  {JXG.Coords}    zero  The Coords-object of line's zero
          * @param  {Number|String} value A predefined value for this tick
-         * @return {String}
+         * @returns {String}
          * @private
          */
         generateLabelText: function (tick, zero, value) {
@@ -785,6 +803,11 @@ define([
                         labelText = labelText + this.visProp.scalesymbol;
                     }
                 }
+
+                if (this.visProp.useunicodeminus) {
+                    labelText = labelText.replace(/-/g, '\u2212');
+                }
+
             }
 
             return labelText;
@@ -795,7 +818,7 @@ define([
          * @param  {String}     labelText
          * @param  {JXG.Coords} tick
          * @param  {Number}     tickNumber
-         * @return {JXG.Text}
+         * @returns {JXG.Text}
          * @private
          */
         generateLabel: function (labelText, tick, tickNumber) {
@@ -933,7 +956,7 @@ define([
      *   var p2 = board.create('point', [1, 3]);
      *   var l1 = board.create('line', [p1, p2]);
      *   var t = board.create('ticks', [l1], {ticksDistance: 2});
-     * </pre><div id="ee7f2d68-75fc-4ec0-9931-c76918427e63" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="ee7f2d68-75fc-4ec0-9931-c76918427e63" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('ee7f2d68-75fc-4ec0-9931-c76918427e63', {boundingbox: [-1, 7, 7, -1], showcopyright: false, shownavigation: false});
@@ -961,13 +984,14 @@ define([
         }
 
         // deprecated
-        if (typeof attr.generatelabelvalue === 'function') {
+        if (Type.isFunction(attr.generatelabelvalue)) {
             el.generateLabelText = attr.generatelabelvalue;
         }
-        if (typeof attr.generatelabeltext === 'function') {
+        if (Type.isFunction(attr.generatelabeltext)) {
             el.generateLabelText = attr.generatelabeltext;
         }
 
+        el.setParents(parents[0]);
         el.isDraggable = true;
 
         return el;
@@ -990,7 +1014,7 @@ define([
      *   var p2 = board.create('point', [1, 3]);
      *   var l1 = board.create('line', [p1, p2]);
      *   var t = board.create('hatch', [l1, 3]);
-     * </pre><div id="4a20af06-4395-451c-b7d1-002757cf01be" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="4a20af06-4395-451c-b7d1-002757cf01be" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('4a20af06-4395-451c-b7d1-002757cf01be', {boundingbox: [-1, 7, 7, -1], showcopyright: false, shownavigation: false});
@@ -1021,6 +1045,8 @@ define([
 
         el = board.create('ticks', [parents[0], pos], attr);
         el.elType = 'hatch';
+
+        return el;
     };
 
     JXG.registerElement('ticks', JXG.createTicks);
