@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2015
+    Copyright 2008-2016
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -77,7 +77,7 @@ define([
      * var p3 = board.create('point', [3.5, 1.0]);
      *
      * var a = board.create('arc', [p1, p2, p3]);
-     * </pre><div id="114ef584-4a5e-4686-8392-c97501befb5b" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="114ef584-4a5e-4686-8392-c97501befb5b" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('114ef584-4a5e-4686-8392-c97501befb5b', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -106,13 +106,7 @@ define([
         el = board.create('curve', [[0], [0]], attr);
 
         el.elType = 'arc';
-
-        el.parents = [];
-        for (i = 0; i < points.length; i++) {
-            if (points[i].id) {
-                el.parents.push(points[i].id);
-            }
-        }
+        el.setParents(points);
 
         /**
          * documented in JXG.GeometryElement
@@ -219,6 +213,7 @@ define([
          * @returns {Number}
          */
         el.getRadius = function () {
+            JXG.deprecated('Arc.getRadius()', 'Arc.Radius()');
             return this.Radius();
         };
 
@@ -362,7 +357,8 @@ define([
             radius: 'Radius',
             center: 'center',
             radiuspoint: 'radiuspoint',
-            anglepoint: 'anglepoint'
+            anglepoint: 'anglepoint',
+            Value: 'Value'
         });
 
         el.prepareUpdate().update();
@@ -387,7 +383,7 @@ define([
      * var p2 = board.create('point', [1.0, 0.5]);
      *
      * var a = board.create('semicircle', [p1, p2]);
-     * </pre><div id="5385d349-75d7-4078-b732-9ae808db1b0e" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="5385d349-75d7-4078-b732-9ae808db1b0e" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('5385d349-75d7-4078-b732-9ae808db1b0e', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -416,7 +412,7 @@ define([
         attr = Type.copyAttributes(attributes, board.options, 'semicircle');
         el = board.create('arc', [mp, points[1], points[0]], attr);
         el.elType = 'semicircle';
-        el.parents = [points[0].id, points[1].id];
+        el.setParents([points[0].id, points[1].id]);
         el.subs = {
             midpoint: mp
         };
@@ -452,7 +448,7 @@ define([
      * var p3 = board.create('point', [3.5, 1.0]);
      *
      * var a = board.create('arc', [p1, p2, p3]);
-     * </pre><div id="87125fd4-823a-41c1-88ef-d1a1369504e3" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="87125fd4-823a-41c1-88ef-d1a1369504e3" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('87125fd4-823a-41c1-88ef-d1a1369504e3', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -484,7 +480,7 @@ define([
         el = board.create('arc', [mp, points[0], points[2], points[1]], attr);
 
         el.elType = 'circumcirclearc';
-        el.parents = [points[0].id, points[1].id, points[2].id];
+        el.setParents([points[0].id, points[1].id, points[2].id]);
         el.subs = {
             center: mp
         };
@@ -521,7 +517,7 @@ define([
      * var p3 = board.create('point', [3.5, 1.0]);
      *
      * var a = board.create('arc', [p1, p2, p3]);
-     * </pre><div id="64ba7ca2-8728-45f3-96e5-3c7a4414de2f" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="64ba7ca2-8728-45f3-96e5-3c7a4414de2f" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('64ba7ca2-8728-45f3-96e5-3c7a4414de2f', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -560,7 +556,7 @@ define([
      * var p3 = board.create('point', [3.5, 1.0]);
      *
      * var a = board.create('minorarc', [p1, p2, p3]);
-     * </pre><div id="17a10d38-5629-40a4-b150-f41806edee9f" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="17a10d38-5629-40a4-b150-f41806edee9f" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('17a10d38-5629-40a4-b150-f41806edee9f', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
