@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2015
+    Copyright 2008-2016
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -76,7 +76,7 @@ define([
      * var B = board.create('point', [-1,-4]);
      * var C = board.create('point', [1,1]);
      * var el = board.create('ellipse',[A,B,C]);
-     * </pre><div id="a4d7fb6f-8708-4e45-87f2-2379ae2bd2c0" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="a4d7fb6f-8708-4e45-87f2-2379ae2bd2c0" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var glex1_board = JXG.JSXGraph.initBoard('a4d7fb6f-8708-4e45-87f2-2379ae2bd2c0', {boundingbox:[-6,6,6,-6], keepaspectratio:true, showcopyright: false, shownavigation: false});
      *   var A = glex1_board.create('point', [-1,4]);
@@ -102,7 +102,7 @@ define([
             } else if (Type.isPoint(parents[i])) {
                 F[i] = board.select(parents[i]);
             // given by function
-            } else if ((typeof parents[i] === 'function') && (Type.isPoint(parents[i]()) )) {
+            } else if (Type.isFunction(parents[i]) && Type.isPoint(parents[i]()) ) {
                 F[i] = parents[i]();
             // focus i given by point name
             } else if (Type.isString(parents[i])) {
@@ -117,7 +117,7 @@ define([
         // length of major axis
         if (Type.isNumber(parents[2])) {
             majorAxis = Type.createFunction(parents[2], board);
-        } else if ((typeof parents[2] === 'function') && (Type.isNumber(parents[2]()))) {
+        } else if (Type.isFunction(parents[2]) && Type.isNumber(parents[2]())) {
             majorAxis = parents[2];
         } else {
             // point on ellipse
@@ -127,7 +127,7 @@ define([
             } else if (parents[2].length > 1) {
                 C = board.create('point', parents[2], attr_foci);
             // given by function
-            } else if ((typeof parents[2] === 'function') && (Type.isPoint(parents[2]()) )) {
+            } else if (Type.isFunction(parents[2]) && Type.isPoint(parents[2]()) ) {
                 C = parents[2]();
             // focus i given by point name
             } else if (Type.isString(parents[2])) {
@@ -260,12 +260,7 @@ define([
         if (Type.isPoint(C)) {
             C.addChild(curve);
         }
-        curve.parents = [];
-        for (i = 0; i < parents.length; i++) {
-            if (parents[i].id) {
-                curve.parents.push(parents[i].id);
-            }
-        }
+        curve.setParents(parents);
 
         return curve;
     };
@@ -291,7 +286,7 @@ define([
      * var B = board.create('point', [-1,-4]);
      * var C = board.create('point', [1,1]);
      * var el = board.create('hyperbola',[A,B,C]);
-     * </pre><div id="cf99049d-a3fe-407f-b936-27d76550f8c4" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="cf99049d-a3fe-407f-b936-27d76550f8c4" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var glex1_board = JXG.JSXGraph.initBoard('cf99049d-a3fe-407f-b936-27d76550f8c4', {boundingbox:[-6,6,6,-6], keepaspectratio:true, showcopyright: false, shownavigation: false});
      *   var A = glex1_board.create('point', [-1,4]);
@@ -316,7 +311,7 @@ define([
             } else if (Type.isPoint(parents[i])) {
                 F[i] = board.select(parents[i]);
             // given by function
-            } else if ((typeof parents[i] === 'function') && (Type.isPoint(parents[i]()) )) {
+            } else if (Type.isFunction(parents[i]) && Type.isPoint(parents[i]()) ) {
                 F[i] = parents[i]();
             // focus i given by point name
             } else if (Type.isString(parents[i])) {
@@ -331,7 +326,7 @@ define([
         // length of major axis
         if (Type.isNumber(parents[2])) {
             majorAxis = Type.createFunction(parents[2], board);
-        } else if ((typeof parents[2] === 'function') && (Type.isNumber(parents[2]()))) {
+        } else if (Type.isFunction(parents[2]) && Type.isNumber(parents[2]())) {
             majorAxis = parents[2];
         } else {
             // point on ellipse
@@ -341,7 +336,7 @@ define([
             } else if (parents[2].length > 1) {
                 C = board.create('point', parents[2], attr_foci);
             // given by function
-            } else if ((typeof parents[2] === 'function') && (Type.isPoint(parents[2]()))) {
+            } else if (Type.isFunction(parents[2]) && Type.isPoint(parents[2]())) {
                 C = parents[2]();
             // focus i given by point name
             } else if (Type.isString(parents[2])) {
@@ -412,7 +407,7 @@ define([
 
         /** @ignore */
         curve.X = function (phi, suspendUpdate) {
-            var r = this.majorAxis(),
+            var r = majorAxis(),
                 c = F[1].Dist(F[0]),
                 b = 0.5 * (c * c - r * r) / (c * Math.cos(phi) + r),
                 beta = Math.atan2(F[1].Y() - F[0].Y(), F[1].X() - F[0].X());
@@ -426,7 +421,7 @@ define([
 
         /** @ignore */
         curve.Y = function (phi, suspendUpdate) {
-            var r = this.majorAxis(),
+            var r = majorAxis(),
                 c = F[1].Dist(F[0]),
                 b = 0.5 * (c * c - r * r) / (c * Math.cos(phi) + r),
                 beta = Math.atan2(F[1].Y() - F[0].Y(), F[1].X() - F[0].X());
@@ -446,12 +441,7 @@ define([
         if (Type.isPoint(C)) {
             C.addChild(curve);
         }
-        curve.parents = [];
-        for (i = 0; i < parents.length; i++) {
-            if (parents[i].id) {
-                curve.parents.push(parents[i].id);
-            }
-        }
+        curve.setParents(parents);
 
         return curve;
     };
@@ -474,7 +464,7 @@ define([
      * var l = board.create('line', [A,B]);
      * var C = board.create('point', [1,1]);
      * var el = board.create('parabola',[C,l]);
-     * </pre><div id="524d1aae-217d-44d4-ac58-a19c7ab1de36" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="524d1aae-217d-44d4-ac58-a19c7ab1de36" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var glex1_board = JXG.JSXGraph.initBoard('524d1aae-217d-44d4-ac58-a19c7ab1de36', {boundingbox:[-6,6,6,-6], keepaspectratio:true, showcopyright: false, shownavigation: false});
      *   var A = glex1_board.create('point', [-1,4]);
@@ -500,7 +490,7 @@ define([
         } else if (Type.isPoint(parents[0])) {
             F1 = board.select(parents[0]);
         // given by function
-        } else if ((typeof parents[0] === 'function') && (Type.isPoint(parents[0]()) )) {
+        } else if (Type.isFunction(parents[0]) && Type.isPoint(parents[0]()) ) {
             F1 = parents[0]();
         // focus i given by point name
         } else if (Type.isString(parents[0])) {
@@ -615,13 +605,7 @@ define([
         }
 
         l.addChild(curve);
-        curve.parents = [];
-
-        for (i = 0; i < parents.length; i++) {
-            if (parents[i].id) {
-                curve.parents.push(parents[i].id);
-            }
-        }
+        curve.setParents(parents);
 
         return curve;
     };
@@ -646,7 +630,7 @@ define([
      *  var D = board.create('point', [0,0]);
      *  var E = board.create('point', [-1,5]);
      *  var conic = board.create('conic',[A,B,C,D,E]);
-     * </pre><div id="2d79bd6a-db9b-423c-9cba-2497f0b06320" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="2d79bd6a-db9b-423c-9cba-2497f0b06320" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var glex1_board = JXG.JSXGraph.initBoard('2d79bd6a-db9b-423c-9cba-2497f0b06320', {boundingbox:[-6,6,6,-6], keepaspectratio:true, showcopyright: false, shownavigation: false});
      *   var A = glex1_board.create('point', [1,5]);
@@ -693,7 +677,7 @@ define([
                 } else if (Type.isPoint(parents[i])) {
                     points[i] = board.select(parents[i]);
                 // given by function
-                } else if ((typeof parents[i] === 'function') && (Type.isPoint(parents[i]()) )) {
+                } else if (Type.isFunction(parents[i]) && Type.isPoint(parents[i]()) ) {
                     points[i] = parents[i]();
                 // point i given by point name
                 } else if (Type.isString(parents[i])) {
@@ -904,12 +888,7 @@ define([
                     points[i].addChild(curve);
                 }
             }
-            curve.parents = [];
-            for (i = 0; i < parents.length; i++) {
-                if (parents[i].id) {
-                    curve.parents.push(parents[i].id);
-                }
-            }
+            curve.setParents(parents);
         }
         curve.addChild(curve.midpoint);
 
