@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2015
+    Copyright 2008-2016
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -81,7 +81,7 @@ define([
      *     p3 = board.create('point', [5.0, 3.0]),
      *
      *     a = board.create('sector', [p1, p2, p3]);
-     * </pre><div id="49f59123-f013-4681-bfd9-338b89893156" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="49f59123-f013-4681-bfd9-338b89893156" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('49f59123-f013-4681-bfd9-338b89893156', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -106,7 +106,7 @@ define([
      *  sec1 = board.create('sector', [li1, li2, [5.5, 0], [4, 3], 3]),
      *  sec2 = board.create('sector', [li1, li2, 1, -1, 4]);
      *
-     * </pre><div id="bb9e2809-9895-4ff1-adfa-c9c71d50aa53" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="bb9e2809-9895-4ff1-adfa-c9c71d50aa53" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('bb9e2809-9895-4ff1-adfa-c9c71d50aa53', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -165,7 +165,7 @@ define([
 
             el.line1.addChild(el);
             el.line2.addChild(el);
-            el.parents = [parents[0].id, parents[1].id];
+            el.setParents(parents);
 
             el.point1 = {visProp: {}};
             el.point2 = {visProp: {}};
@@ -295,7 +295,7 @@ define([
 
             // useDirection is necessary for circumCircleSectors
             el.useDirection = attributes.usedirection;
-            el.parents = [points[0].id, points[1].id, points[2].id];
+            el.setParents(points);
 
             /**
             * Defines the sectors orientation in case of circumCircleSectors.
@@ -402,6 +402,12 @@ define([
                 alpha = 0;
                 beta = Geometry.rad(this.point2, this.center, this.point3);
 
+                if ((this.visProp.selection === 'minor' && beta > Math.PI) ||
+                        (this.visProp.selection === 'major' && beta < Math.PI)) {
+                    alpha = beta;
+                    beta = 2 * Math.PI;
+                }
+
                 if (angle < alpha || angle > beta) {
                     has = false;
                 }
@@ -510,10 +516,11 @@ define([
         };
 
         /**
-         * deprecated
+         * @deprecated
          * @ignore
          */
         el.getRadius = function () {
+            JXG.deprecated('Sector.getRadius()', 'Sector.Radius()');
             return this.Radius();
         };
 
@@ -569,7 +576,7 @@ define([
      *     p3 = board.create('point', [5.0, 3.0]),
      *
      *     a = board.create('circumcirclesector', [p1, p2, p3]);
-     * </pre><div id="695cf0d6-6d7a-4d4d-bfc9-34c6aa28cd04" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="695cf0d6-6d7a-4d4d-bfc9-34c6aa28cd04" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
  *   var board = JXG.JSXGraph.initBoard('695cf0d6-6d7a-4d4d-bfc9-34c6aa28cd04', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -597,7 +604,7 @@ define([
         el = board.create('sector', [mp, points[0], points[2], points[1]], attr);
 
         el.elType = 'circumcirclesector';
-        el.parents = [points[0].id, points[1].id, points[2].id];
+        el.setParents(points);
 
         /**
          * Center of the circumcirclesector
@@ -634,7 +641,7 @@ define([
      * var p3 = board.create('point', [3.5, 1.0]);
      *
      * var a = board.create('minorsector', [p1, p2, p3]);
-     * </pre><div id="af27ddcc-265f-428f-90dd-d31ace945800" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="af27ddcc-265f-428f-90dd-d31ace945800" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('af27ddcc-265f-428f-90dd-d31ace945800', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -672,7 +679,7 @@ define([
      * var p3 = board.create('point', [3.5, 1.0]);
      *
      * var a = board.create('majorsector', [p1, p2, p3]);
-     * </pre><div id="83c6561f-7561-4047-b98d-036248a00932" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox"id="83c6561f-7561-4047-b98d-036248a00932" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('83c6561f-7561-4047-b98d-036248a00932', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -721,8 +728,9 @@ define([
      *     p2 = board.create('point', [1.0, 0.5]),
      *     p3 = board.create('point', [1.5, 5.0]),
      *
-     *     a = board.create('angle', [p1, p2, p3]);
-     * </pre><div id="a34151f9-bb26-480a-8d6e-9b8cbf789ae5" style="width: 300px; height: 300px;"></div>
+     *     a = board.create('angle', [p1, p2, p3]),
+     *     t = board.create('text', [4, 4, function() { return a.Value().toFixed(2); }]);
+     * </pre><div class="jxgbox"id="a34151f9-bb26-480a-8d6e-9b8cbf789ae5" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('a34151f9-bb26-480a-8d6e-9b8cbf789ae5', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -730,7 +738,8 @@ define([
      *     p2 = board.create('point', [1.0, 0.5]),
      *     p3 = board.create('point', [1.5, 5.0]),
      *
-     *     a = board.create('angle', [p1, p2, p3]);
+     *     a = board.create('angle', [p1, p2, p3]),
+     *     t = board.create('text', [4, 4, function() { return a.Value().toFixed(2); }]);
      * })();
      * </script><pre>
      *
@@ -747,7 +756,8 @@ define([
      *  a1 = board.create('angle', [li1, li2, [5.5, 0], [4, 3]], { radius:1 }),
      *  a2 = board.create('angle', [li1, li2, 1, -1], { radius:2 });
      *
-     * </pre><div id="3a667ddd-63dc-4594-b5f1-afac969b371f" style="width: 300px; height: 300px;"></div>
+     *
+     * </pre><div class="jxgbox"id="3a667ddd-63dc-4594-b5f1-afac969b371f" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('3a667ddd-63dc-4594-b5f1-afac969b371f', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -869,6 +879,89 @@ define([
             * @param {Number|Function} val Number or Function which returns the size of the angle in Radians
             * @returns {Object} Pointer to the angle element..
             * @memberOf Angle.prototype
+            *
+            * @example
+            * var p1, p2, p3, c, a, s;
+            *
+            * p1 = board.create('point',[0,0]);
+            * p2 = board.create('point',[5,0]);
+            * p3 = board.create('point',[0,5]);
+            *
+            * c1 = board.create('circle',[p1, p2]);
+            *
+            * a = board.create('angle',[p2, p1, p3], {radius:3});
+            *
+            * a.setAngle(function() {
+            *     return Math.PI / 3;
+            * });
+            * board.update();
+            *
+            * </pre><div id="987c-394f-11e6-af4a-901b0e1b8723" class="jxgbox" style="width: 300px; height: 300px;"></div>
+            * <script type="text/javascript">
+            *     (function() {
+            *         var board = JXG.JSXGraph.initBoard('987c-394f-11e6-af4a-901b0e1b8723',
+            *             {boundingbox: [-8, 8, 8,-8], axis: true, showcopyright: false, shownavigation: false});
+            *     var p1, p2, p3, c, a, s;
+            *
+            *     p1 = board.create('point',[0,0]);
+            *     p2 = board.create('point',[5,0]);
+            *     p3 = board.create('point',[0,5]);
+            *
+            *     c1 = board.create('circle',[p1, p2]);
+            *
+            *     a = board.create('angle',[p2, p1, p3], {radius: 3});
+            *
+            *     a.setAngle(function() {
+            *         return Math.PI / 3;
+            *     });
+            *     board.update();
+            *
+            *     })();
+            *
+            * </script><pre>
+            *
+            * @example
+            * var p1, p2, p3, c, a, s;
+            *
+            * p1 = board.create('point',[0,0]);
+            * p2 = board.create('point',[5,0]);
+            * p3 = board.create('point',[0,5]);
+            *
+            * c1 = board.create('circle',[p1, p2]);
+            *
+            * a = board.create('angle',[p2, p1, p3], {radius:3});
+            * s = board.create('slider',[[-2,1], [2,1], [0, Math.PI*0.5, 2*Math.PI]]);
+            *
+            * a.setAngle(function() {
+            *     return s.Value();
+            * });
+            * board.update();
+            *
+            * </pre><div id="99957b1c-394f-11e6-af4a-901b0e1b8723" class="jxgbox" style="width: 300px; height: 300px;"></div>
+            * <script type="text/javascript">
+            *     (function() {
+            *         var board = JXG.JSXGraph.initBoard('99957b1c-394f-11e6-af4a-901b0e1b8723',
+            *             {boundingbox: [-8, 8, 8,-8], axis: true, showcopyright: false, shownavigation: false});
+            *     var p1, p2, p3, c, a, s;
+            *
+            *     p1 = board.create('point',[0,0]);
+            *     p2 = board.create('point',[5,0]);
+            *     p3 = board.create('point',[0,5]);
+            *
+            *     c1 = board.create('circle',[p1, p2]);
+            *
+            *     a = board.create('angle',[p2, p1, p3], {radius: 3});
+            *     s = board.create('slider',[[-2,1], [2,1], [0, Math.PI*0.5, 2*Math.PI]]);
+            *
+            *     a.setAngle(function() {
+            *         return s.Value();
+            *     });
+            *     board.update();
+            *
+            *     })();
+            *
+            * </script><pre>
+            *
             */
             el.setAngle = function (val) {
                 var t,
@@ -879,7 +972,7 @@ define([
                     t = this.board.create('transform', [val, this.center], {type: 'rotate'});
                     p.addTransform(q, t);
                     p.isDraggable = false;
-                    p.parents = [q];
+                    p.setParents(q);
                 }
                 return this;
             };
@@ -902,7 +995,7 @@ define([
                 return this;
             };
 
-            el.parents = [points[0].id, points[1].id, points[2].id]; // Important: This overwrites the parents order in underlying sector
+            el.setParents(points); // Important: This overwrites the parents order in underlying sector
 
         } // end '3points'
 
@@ -913,7 +1006,6 @@ define([
 
         el.elType = 'angle';
         el.type = Const.OBJECT_TYPE_ANGLE;
-        // el.parents = [points[0].id, points[1].id, points[2].id];
         el.subs = {};
 
         el.updateDataArraySquare = function () {
@@ -1098,6 +1190,13 @@ define([
             return new Coords(Const.COORDS_BY_USER, vec, this.board);
         };
 
+        /**
+         * Returns the value of the angle in Radians.
+         * @memberOf Angle.prototype
+         * @name Value
+         * @function
+         * @returns {Number} The angle value in Radians
+         */
         el.Value = function () {
             return Geometry.rad(this.point2, this.point1, this.point3);
         };
@@ -1114,12 +1213,12 @@ define([
     JXG.registerElement('angle', JXG.createAngle);
 
     /**
-     * @class A non-reflex angle is the acute or obtuse instance of an angle. 
+     * @class A non-reflex angle is the acute or obtuse instance of an angle.
      * It is defined by a center, one point that
      * defines the radius, and a third point that defines the angle of the sector.
      * @pseudo
      * @name NonReflexAngle
-     * @augments Sector
+     * @augments Angle
      * @constructor
      * @type Sector
      * @throws {Error} If the element cannot be constructed with the given parent objects an exception is thrown.
@@ -1131,8 +1230,9 @@ define([
      *     p2 = board.create('point', [1.0, 0.5]),
      *     p3 = board.create('point', [1.5, 5.0]),
      *
-     *     a = board.create('nonreflexangle', [p1, p2, p3], {radius: 2});
-     * </pre><div id="d0ab6d6b-63a7-48b2-8749-b02bb5e744f9" style="width: 300px; height: 300px;"></div>
+     *     a = board.create('nonreflexangle', [p1, p2, p3], {radius: 2}),
+     *     t = board.create('text', [4, 4, function() { return a.Value().toFixed(2); }]);
+     * </pre><div class="jxgbox"id="d0ab6d6b-63a7-48b2-8749-b02bb5e744f9" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('d0ab6d6b-63a7-48b2-8749-b02bb5e744f9', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -1140,24 +1240,33 @@ define([
      *     p2 = board.create('point', [1.0, 0.5]),
      *     p3 = board.create('point', [1.5, 5.0]),
      *
-     *     a = board.create('nonreflexangle', [p1, p2, p3], {radius: 2});
+     *     a = board.create('nonreflexangle', [p1, p2, p3], {radius: 2}),
+     *     t = board.create('text', [4, 4, function() { return a.Value().toFixed(2); }]);
      * })();
      * </script><pre>
      */
     JXG.createNonreflexAngle = function (board, parents, attributes) {
+        var el;
+
         attributes.selection = 'minor';
-        return JXG.createAngle(board, parents, attributes);
+        el = JXG.createAngle(board, parents, attributes);
+
+        el.Value = function () {
+            var v = Geometry.rad(this.point2, this.point1, this.point3);
+            return (v < Math.PI) ? v : 2.0 * Math.PI - v;
+        };
+        return el;
     };
 
     JXG.registerElement('nonreflexangle', JXG.createNonreflexAngle);
 
     /**
-     * @class A reflex angle is the neither acute nor obtuse instance of an angle. 
+     * @class A reflex angle is the neither acute nor obtuse instance of an angle.
      * It is defined by a center, one point that
      * defines the radius, and a third point that defines the angle of the sector.
      * @pseudo
      * @name ReflexAngle
-     * @augments Sector
+     * @augments Angle
      * @constructor
      * @type Sector
      * @throws {Error} If the element cannot be constructed with the given parent objects an exception is thrown.
@@ -1169,27 +1278,36 @@ define([
      *     p2 = board.create('point', [1.0, 0.5]),
      *     p3 = board.create('point', [1.5, 5.0]),
      *
-     *     a = board.create('reflexangle', [p1, p2, p3], {radius: 2});
-     * </pre><div id="f2a577f2-553d-4f9f-a895-2d6d4b8c60e8" style="width: 300px; height: 300px;"></div>
+     *     a = board.create('reflexangle', [p1, p2, p3], {radius: 2}),
+     *     t = board.create('text', [4, 4, function() { return a.Value().toFixed(2); }]);
+     * </pre><div class="jxgbox"id="f2a577f2-553d-4f9f-a895-2d6d4b8c60e8" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
-     *   var board = JXG.JSXGraph.initBoard('f2a577f2-553d-4f9f-a895-2d6d4b8c60e8', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
+     * var board = JXG.JSXGraph.initBoard('f2a577f2-553d-4f9f-a895-2d6d4b8c60e8', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
      *     p1 = board.create('point', [5.0, 3.0]),
      *     p2 = board.create('point', [1.0, 0.5]),
      *     p3 = board.create('point', [1.5, 5.0]),
      *
-     *     a = board.create('reflexangle', [p1, p2, p3], {radius: 2});
+     *     a = board.create('reflexangle', [p1, p2, p3], {radius: 2}),
+     *     t = board.create('text', [4, 4, function() { return a.Value().toFixed(2); }]);
      * })();
      * </script><pre>
      */
     JXG.createReflexAngle = function (board, parents, attributes) {
+        var el;
+
         attributes.selection = 'major';
-        return JXG.createAngle(board, parents, attributes);
+        el = JXG.createAngle(board, parents, attributes);
+
+        el.Value = function () {
+            var v = Geometry.rad(this.point2, this.point1, this.point3);
+            return (v >= Math.PI) ? v : 2.0 * Math.PI - v;
+        };
+        return el;
     };
 
     JXG.registerElement('reflexangle', JXG.createReflexAngle);
 
-
     return {
         createSector: JXG.createSector,
         createCircumcircleSector: JXG.createCircumcircleSector,
