@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2015
+    Copyright 2008-2016
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -72,7 +72,7 @@ define([
          * @param {JXG.Point,Array} A A point  or [x,y] array.
          * @param {JXG.Point,Array} B Another point or [x,y] array.
          * @param {JXG.Point,Array} C A circle - no, of course the third point or [x,y] array.
-         * @deprecated Use {@link JXG.Math.Geometry#rad} instead.
+         * @deprecated Use {@link JXG.Math.Geometry.rad} instead.
          * @see #rad
          * @see #trueAngle
          * @returns {Number} The angle in radian measure.
@@ -83,6 +83,7 @@ define([
                 b = [],
                 c = [];
 
+            JXG.deprecated('Geometry.angle()', 'Geometry.rad()');
             if (A.coords) {
                 a[0] = A.coords.usrCoords[1];
                 a[1] = A.coords.usrCoords[2];
@@ -361,9 +362,12 @@ define([
         },
 
         /**
-         * @deprecated Please use {@link JXG.Math.Geometry#circumcenter} instead.
+         * @deprecated Please use {@link JXG.Math.Geometry.circumcenter} instead.
          */
-        circumcenterMidpoint: JXG.shortcut(Mat.Geometry, 'circumcenter'),
+        circumcenterMidpoint: function () {
+            JXG.deprecated('Geometry.circumcenterMidpoint()', 'Geometry.circumcenter()');
+            this.circumcenter.apply(this, arguments);
+        },
 
         /**
          * Calculates the center of the circumcircle of the three given points.
@@ -498,6 +502,7 @@ define([
 
         /**
          * Determine the signed area of a non-intersecting polygon.
+         * Surveyor's Formula
          *
          * @param {Array} p An array containing {@link JXG.Point}, {@link JXG.Coords}, and/or arrays.
          * @param {Boolean} [sort=true]
@@ -509,6 +514,10 @@ define([
                 A = 0,
                 ps = Expect.each(p, Expect.coordsArray);
 
+            if (sort === undefined) {
+                sort = true;
+            }
+
             if (!sort) {
                 ps = this.sortVertices(ps);
             } else {
@@ -534,12 +543,11 @@ define([
          * @returns {Array}
          */
         GrahamScan: function (points) {
-            var i, ll,
+            var i,
                 M = 1,
                 ps = Expect.each(points, Expect.coordsArray),
                 N = ps.length;
 
-
             ps = this.sortVertices(ps);
             N = ps.length;
 
@@ -576,7 +584,7 @@ define([
          */
         calcStraight: function (el, point1, point2, margin) {
             var takePoint1, takePoint2, intersection, intersect1, intersect2, straightFirst, straightLast,
-                c, s, i, j, p1, p2;
+                c, p1, p2;
 
             if (!Type.exists(margin)) {
                 // Enlarge the drawable region slightly. This hides the small sides
@@ -703,7 +711,6 @@ define([
             }
         },
 
-
         /**
          * A line can be a segment, a straight, or a ray. so it is not always delimited by point1 and point2.
          *
@@ -724,8 +731,8 @@ define([
          */
         calcLineDelimitingPoints: function (el, point1, point2) {
             var distP1P2, boundingBox, lineSlope,
-                intersection, intersect1, intersect2, straightFirst, straightLast,
-                c, s, i, j, p1, p2,
+                intersect1, intersect2, straightFirst, straightLast,
+                c, p1, p2,
                 takePoint1 = false,
                 takePoint2 = false;
 
@@ -930,17 +937,18 @@ define([
         /****************************************/
 
         /**
-         * Generate the function which computes the coordinates of the intersection point. 
+         * Generate the function which computes the coordinates of the intersection point.
          * Primarily used in {@link JXG.Point#createIntersectionPoint}.
          * @param {JXG.Board} board object
-         * @param {JXG.Line,JXG.Circle_JXG.Line,JXG.Circle_Number} el1,el2,i The result will be a intersection point on el1 and el2. 
+         * @param {JXG.Line,JXG.Circle_JXG.Line,JXG.Circle_Number} el1,el2,i The result will be a intersection point on el1 and el2.
          * i determines the intersection point if two points are available: <ul>
          *   <li>i==0: use the positive square root,</li>
          *   <li>i==1: use the negative square root.</li></ul>
-         * See further {@see JXG.Point#createIntersectionPoint}.
-         * @param {Boolean} alwaysintersect. Flag that determines if segements and arc can have an outer intersection point 
+         * See further {@link JXG.Point#createIntersectionPoint}.
+         * @param {Boolean} alwaysintersect. Flag that determines if segements and arc can have an outer intersection point
          * on their defining line or circle.
-         * @returns {Function} Function returning a {@see JXG.Coords} object that determines the intersection point.
+         * @returns {Function} Function returning a {@link JXG.Coords} object that determines
+         * the intersection point.
          */
         intersectionFunction: function (board, el1, el2, i, j, alwaysintersect) {
             var func, that = this;
@@ -1052,10 +1060,10 @@ define([
 
         /**
          * Intersection of the line with the board
-         * @param  {Array}     line   stdform of the line
+         * @param  {Array}     line   stdform of the line in screen coordinates
          * @param  {JXG.Board} board  reference to a board.
          * @param  {Number}    margin optional margin, to avoid the display of the small sides of lines.
-         * @return {Array}            [intersection coords 1, intersection coords 2]
+         * @returns {Array}            [intersection coords 1, intersection coords 2]
          */
         meetLineBoard: function (line, board, margin) {
              // Intersect the line with the four borders of the board.
@@ -1289,7 +1297,7 @@ define([
          * the ideal point [0,1,0] is returned.
          */
         meetCurveLine: function (el1, el2, nr, board, alwaysIntersect) {
-            var v = [0, NaN, NaN], i, cu, li;
+            var v = [0, NaN, NaN], cu, li;
 
             if (!Type.exists(board)) {
                 board = el1.board;
@@ -1315,8 +1323,9 @@ define([
         /**
          * Intersection of line and curve, continuous case.
          * Finds the nr-the intersection point
-         * Uses {@link JXG.Math.Geometry#meetCurveLineDiscrete} as a first approximation.
-         * A more exact solution is then found with {@link JXG.Math.Numerics#meetCurveLineDiscrete}.
+         * Uses {@link JXG.Math.Geometry.meetCurveLineDiscrete} as a first approximation.
+         * A more exact solution is then found with
+         * {@link JXG.Math.Geometry.meetCurveLineDiscrete}.
          *
          * @param {JXG.Curve} cu Curve
          * @param {JXG.Line} li Line
@@ -1325,8 +1334,11 @@ define([
          *
          */
         meetCurveLineContinuous: function (cu, li, nr, board, testSegment) {
-            var t, func0, func1, v, x, y, z,
-                eps = Mat.eps * 10;
+            var t, func0, func1, func0a, v, x, y, z,
+                eps = Mat.eps,
+                epsLow = Mat.eps,
+                steps, delta, tnew, i,
+                tmin, fmin;
 
             v = this.meetCurveLineDiscrete(cu, li, nr, board, testSegment);
             x = v.usrCoords[1];
@@ -1336,7 +1348,7 @@ define([
                 var c1 = x - cu.X(t),
                     c2 = y - cu.Y(t);
 
-                return Math.sqrt(c1 * c1 + c2 * c2);
+                return c1 * c1 + c2 * c2;
             };
 
             func1 = function (t) {
@@ -1345,12 +1357,28 @@ define([
             };
 
             // Find t
-            t = Numerics.root(func0, [cu.minX(), cu.maxX()]);
-            // Compute "exect" t
-            t = Numerics.root(func1, t);
+            steps = 100;
+            delta = (cu.maxX() - cu.minX()) / steps;
+            tnew = cu.minX();
+
+            fmin = 0.0001; //eps;
+            tmin = NaN;
+            for (i = 0; i < steps; i++) {
+                t = Numerics.root(func0, [tnew, tnew + delta]);
+                if (Math.abs(func0(t)) <= fmin  ) {
+                    fmin = Math.abs(func0(t));
+                    tmin = t;
+                    //break;
+                }
+
+                tnew += delta;
+            }
+            t = tmin;
+            // Compute "exact" t
+            t = Numerics.root(func1, [t - delta, t + delta]);
 
             // Is the point on the line?
-            if (Math.abs(func1(t)) > eps) {
+            if (Math.abs(func1(t)) > epsLow) {
                 z = NaN;
             } else {
                 z = 1.0;
@@ -1378,8 +1406,8 @@ define([
                 tnew, steps, delta, tstart, tend, cux, cuy,
                 eps = Mat.eps * 10;
 
+            JXG.deprecated('Geometry.meetCurveLineContinuousOld()', 'Geometry.meetCurveLineContinuous()');
             func = function (t) {
-//                return li.stdform[0] + li.stdform[1] * cu.X(t) + li.stdform[2] * cu.Y(t);
                 var v = li.stdform[0] + li.stdform[1] * cu.X(t) + li.stdform[2] * cu.Y(t);
                 return v * v;
             };
@@ -1533,8 +1561,8 @@ define([
                 red1, red2, blue1, blue2, m,
                 minX, maxX,
                 iFound = 0,
-                lenBlue = blue.points.length,
-                lenRed = red.points.length;
+                lenBlue = blue.numberPoints, //points.length,
+                lenRed = red.numberPoints; //points.length;
 
             if (lenBlue <= 1 || lenRed <= 1) {
                 return [0, NaN, NaN];
@@ -1614,8 +1642,7 @@ define([
          * @returns {Array} Array consisting of two coordinate arrays for Bezier curves.
          */
         _bezierSplit: function (curve) {
-            var a = [], b = [],
-                p0, p1, p2, p00, p22, p000;
+            var p0, p1, p2, p00, p22, p000;
 
             p0 = [(curve[0][0] + curve[1][0]) * 0.5, (curve[0][1] + curve[1][1]) * 0.5];
             p1 = [(curve[1][0] + curve[2][0]) * 0.5, (curve[1][1] + curve[2][1]) * 0.5];
@@ -1702,7 +1729,7 @@ define([
          * @param {Array} blue Array of four coordinate arrays of length 2 defining the second
          * Bezier curve segment, i.e. [[x0,y0], [x1,y1], [x2,y2], [x3,y3]].
          * @param {Number} level Recursion level
-         * @returns {Array} List of intersection points (up to nine). Each intersction point is an
+         * @returns {Array} List of intersection points (up to nine). Each intersection point is an
          * array of length three (homogeneous coordinates) plus preimages.
          */
         _bezierMeetSubdivision: function (red, blue, level) {
@@ -1808,7 +1835,7 @@ define([
          *
          */
         meetBeziersegmentBeziersegment: function (red, blue, testSegment) {
-            var L, n, L2, i;
+            var L, L2, i;
 
             if (red.length === 4 && blue.length === 4) {
                 L = this._bezierMeetSubdivision(red, blue, 0);
@@ -1841,8 +1868,8 @@ define([
             var p, i, j,
                 redArr, blueArr,
                 bbr, bbb,
-                lenBlue = blue.points.length,
-                lenRed = red.points.length,
+                lenBlue = blue.numberPoints, //points.length,
+                lenRed = red.numberPoints, // points.length,
                 L = [];
 
             if (lenBlue < 4 || lenRed < 4) {
@@ -1913,7 +1940,7 @@ define([
 
         /**
          * Generate the defining points of a 3rd degree bezier curve that approximates
-         * a cricle sector defined by three arrays A, B,C, each of length three.
+         * a circle sector defined by three arrays A, B,C, each of length three.
          * The coordinate arrays are given in homogeneous coordinates.
          * @param {Array} A First point
          * @param {Array} B Second point (intersection point)
@@ -2080,7 +2107,7 @@ define([
          * two endpoints q1 and q2 of the segment.
          */
         projectCoordsToSegment: function (p, q1, q2) {
-            var t, denom, c,
+            var t, denom,
                 s = [q2[1] - q1[1], q2[2] - q1[2]],
                 v = [p[1] - q1[1], p[2] - q1[2]];
 
@@ -2127,7 +2154,8 @@ define([
 
         /**
          * Calculates the coordinates of the projection of a given point on a given curve.
-         * Uses {@link #projectCoordsToCurve}.
+         * Uses {@link JXG.Math.Geometry.projectCoordsToCurve}.
+         *
          * @param {JXG.Point} point Point to project.
          * @param {JXG.Curve} curve Curve on that the point is projected.
          * @param {JXG.Board} [board=point.board] Reference to a board.
@@ -2164,8 +2192,8 @@ define([
          */
         projectCoordsToCurve: function (x, y, t, curve, board) {
             var newCoords, newCoordsObj, i, j,
-                x0, y0, x1, y1, mindist, dist, lbda, li, v, coords, d,
-                p1, p2, q1, q2, res,
+                mindist, dist, lbda, v, coords, d,
+                p1, p2, res,
                 minfunc, tnew, fnew, fold, delta, steps,
                 infty = Number.POSITIVE_INFINITY;
 
@@ -2245,7 +2273,7 @@ define([
                 for (i = 0; i < steps; i++) {
                     fnew = minfunc(tnew);
 
-                    if (fnew < fold) {
+                    if (fnew < fold || isNaN(fold)) {
                         t = tnew;
                         fold = fnew;
                     }
@@ -2304,7 +2332,7 @@ define([
 
         /**
          * Calculates the coordinates of the projection of a given point on a given turtle. A turtle consists of
-         * one or more curves of curveType 'plot'. Uses {@link #projectPointToCurve}.
+         * one or more curves of curveType 'plot'. Uses {@link JXG.Math.Geometry.projectPointToCurve}.
          * @param {JXG.Point} point Point to project.
          * @param {JXG.Turtle} turtle on that the point is projected.
          * @param {JXG.Board} [board=point.board] Reference to a board.
@@ -2423,10 +2451,12 @@ define([
         /**
          * Helper function to create curve which displays a Reuleaux polygons.
          * @param {Array} points Array of points which should be the vertices of the Reuleaux polygon. Typically,
-         * these point list is the array vrtices of a regular polygon.
+         * these point list is the array vertices of a regular polygon.
          * @param {Number} nr Number of vertices
          * @returns {Array} An array containing the two functions defining the Reuleaux polygon and the two values
-         * for the start and the end of the paramtric curve. array may be used as parent array of a {@link JXG.Curve}.
+         * for the start and the end of the paramtric curve. array may be used as parent array of a
+         * {@link JXG.Curve}.
+         *
          * @example
          * var A = brd.create('point',[-2,-2]);
          * var B = brd.create('point',[0,1]);
@@ -2434,7 +2464,7 @@ define([
          * var reuleauxTriangle = brd.create('curve', JXG.Math.Geometry.reuleauxPolygon(pol.vertices, 3),
          *                          {strokeWidth:6, strokeColor:'#d66d55', fillColor:'#ad5544', highlightFillColor:'#ad5544'});
          *
-         * </pre><div id="2543a843-46a9-4372-abc1-94d9ad2db7ac" style="width: 300px; height: 300px;"></div>
+         * </pre><div class="jxgbox"id="2543a843-46a9-4372-abc1-94d9ad2db7ac" style="width: 300px; height: 300px;"></div>
          * <script type="text/javascript">
          * var brd = JXG.JSXGraph.initBoard('2543a843-46a9-4372-abc1-94d9ad2db7ac', {boundingbox: [-5, 5, 5, -5], axis: true, showcopyright:false, shownavigation: false});
          * var A = brd.create('point',[-2,-2]);
