@@ -167,7 +167,7 @@
             gxtEl.labelColor = rgbo[0];
             gxtEl.withLabel = rgbo[1] > 0;
             gxtEl.labelOpacity = rgbo[1];
-            
+
             gxtEl.colorDraft = JXG.rgba2rgbo(this.gEBTN(color, 'draft'))[0];
 
             // backwards compatibility
@@ -237,7 +237,7 @@
          * Transforms the Geonext properties to jsxgraph properties
          * @param {Object} gxtEl
          * @param {String} [type]
-         * @return {Object} gxtEl
+         * @returns {Object} gxtEl
          */
         transformProperties: function (gxtEl, type) {
             var i,
@@ -593,7 +593,7 @@
                 try {
                     gxtEl.parent = this.changeOriginIds(board, gxtEl.parent);
                     gxtEl.isGeonext = true;
-                    
+
                     p = board.create('glider', [parseFloat(gxtEl.x), parseFloat(gxtEl.y), gxtEl.parent], gxtEl);
                     p.onPolygon = JXG.exists(gxtEl.onpolygon) && JXG.str2Bool(gxtEl.onpolygon);
 
@@ -910,14 +910,14 @@
                 // A.W.: Why do we need this?
                 /*
                  if (!gxtEl.visible) {
-                 p.setProperty({
+                 p.setAttribute({
                  fillColor: 'none',
                  highlightFillColor: 'none'
                  });
                  }
                  */
                 for (i = 0; i < p.borders.length; i++) {
-                    p.borders[i].setProperty(gxtEl.border[i]);
+                    p.borders[i].setAttribute(gxtEl.border[i]);
                 }
 
                 this.printDebugMessage('debug', gxtEl, Data.nodeName, 'OK');
@@ -1122,7 +1122,7 @@
             xmlNode = this.gEBTN(boardData, 'coordinates', 0, false);
 
             tmp = this.readViewPort(xmlNode);
-            
+
             if (tmp.length === 4) {
                 board.setBoundingBox(tmp, true);
             } else {
