@@ -1,5 +1,5 @@
 /*
- Copyright 2008-2013
+ Copyright 2008-2016
  Matthias Ehmann,
  Michael Gerhaeuser,
  Carsten Miller,
@@ -72,7 +72,7 @@
             } else {
                 t = meta.unredo;
             }
-            
+
             for (i = 0; i <= t; i++) {
                 if (constr[i].type !== 0) {
                     try {
@@ -223,14 +223,14 @@
                     // x-axis
                     set_str += step.args.name[3] + ' = axis(' + step.args.name[0] + ', ' + step.args.name[1] + ') ';
                     set_str += '<<id: \'' + step.dest_sub_ids[3] + '\', name: \'' + step.args.name[3] + '\', ticks: ';
-                    set_str += '<<minorHeight:0, majorHeight:10, ticksDistance: 1, drawLabels: true';
+                    set_str += '<<minorHeight:0, majorHeight:10, insertTicks: true, ticksDistance: 1, drawLabels: true';
                     set_str += ', label: <<offset: [-4, -16], parse: false, display: "internal">>';
                     set_str += ', drawZero: false>>>>; ';
-                    
+
                     // y-axis
                     set_str += step.args.name[4] + ' = axis(' + step.args.name[0] + ', ' + step.args.name[2] + ') ';
                     set_str += '<<id: \'' + step.dest_sub_ids[4] + '\', name: \'' + step.args.name[4] + '\', ticks: ';
-                    set_str += '<<minorHeight:0, majorHeight:10, ticksDistance: 1, drawLabels: true';
+                    set_str += '<<minorHeight:0, majorHeight:10, insertTicks: true, ticksDistance: 1, drawLabels: true';
                     set_str += ', label: <<offset: [10, 0], parse: false, display: "internal">>';
                     set_str += ', drawZero: false>>>>; ';
 
@@ -424,7 +424,7 @@
                         set_str += ', snapToGrid: false, snapToPoints: false';
                         set_str += '>>; ' + step.dest_id;
                         set_str += '.glide(' + step.src_ids[0] + '); ';
-                    } 
+                    }
                     set_str += step.dest_id + '.onPolygon = ' + !!step.args.onPolygon + ';';
 
                     if (!(step.args && step.args.undoIsEmpty)) {
@@ -673,6 +673,69 @@
 
                     break;
 
+                case JXG.GENTYPE_VECTOR:
+
+                    k = 0;
+                    j = 0;
+
+                    if (step.args.create_point1) {
+                        pid1 = step.dest_sub_ids[k];
+                        k += 1;
+                        str1 = [];
+                        for (i = 0; i < step.args.p1.length; i++) {
+                            str1[i] = pn(step.args.p1[i]);
+                        }
+
+                        set_str = 'point(' + str1.join(', ') + ') <<id: \'' + pid1 + '\', name: \'\', visible: true, ';
+                        set_str += 'snaptogrid: false, snaptopoints: false, priv: false>>; ';
+                        reset_str = 'delete ' + pid1 + '; ';
+                    } else {
+                        pid1 = step.src_ids[j];
+                        j += 1;
+                    }
+
+                    if (step.args.create_point2) {
+                        pid2 = step.dest_sub_ids[k++];
+                        str1 = [];
+                        for (i = 0; i < step.args.p2.length; i++) {
+                            str1[i] = pn(step.args.p2[i]);
+                        }
+
+                        set_str += 'point(' + str1.join(', ') + ') <<id: \'' + pid2 + '\', name: \'\', visible: true, ';
+                        set_str += 'layer: ' + JXG.Options.layer.line + ', opacity: 0.2, ';
+                        set_str += 'snaptogrid: false, snaptopoints: false, priv: false>>; ';
+                        reset_str = 'delete ' + pid2 + '; ' + reset_str;
+                    } else {
+                        pid2 = step.src_ids[j];
+                        j += 1;
+                    }
+
+                    str1 = '';
+                    // the line's parents
+                    str2 = pid1 + ', ' + pid2;
+                    str = 'arrow';
+
+                    // this is a corner case, we have to get rid of the ',' at the end
+                    // simple solution: rebuild attrid
+                    if (!options.useSymbols) {
+                        attrid = 'id: \'' + step.dest_id + '\'';
+                    }
+
+                    set_str += assign + str + '(' + str2 + ')';
+
+                    if (str1.length + attrid.length > 0) {
+                        set_str += ' <<' + str1 + attrid + ', name: \'\', strokeColor: \'black\', snaptogrid: ' + JXG.Options.elements.snapToGrid
+                            + ', snaptopoints: ' + JXG.Options.elements.snapToPoints + '>>; ';
+
+                    } else {
+                        set_str += ' <<name: \'\', strokeColor: \'black\', snaptogrid: ' + JXG.Options.elements.snapToGrid
+                            + ', snaptopoints: ' + JXG.Options.elements.snapToPoints + '>>; ';
+                    }
+
+                    reset_str = 'delete ' + step.dest_id + '; ' + reset_str;
+
+                    break;
+
                 case JXG.GENTYPE_TRIANGLE:
                     for (i = 0; i < step.args.create_point.length; i++) {
                         if (step.args.create_point[i]) {
@@ -856,7 +919,7 @@
                     set_str += ', hasInnerPoints: ' + JXG.Options.polygon.hasInnerPoints;
                     set_str += ', name: \'\'>>; ';
                     reset_str = 'delete ' + step.dest_id + '; ' + reset_str;
-                    
+
                     break;
 
                 case JXG.GENTYPE_SECTOR:
@@ -876,13 +939,36 @@
                     reset_str += 'delete ' + step.dest_sub_ids[0] + '; ';
                     break;
 
+                case JXG.GENTYPE_NONREFLEXANGLE:
+                    set_str = assign + 'nonreflexangle(' + step.src_ids.join(', ') + ') ';
+                    set_str += '<<';
+                    set_str += 'dot: <<priv:true, id: \'' + step.dest_sub_ids[0] + '\', ';
+                    set_str += 'name: \'' + step.dest_sub_ids[0] + '\'>>, ';
+                    set_str += attrid + ' fillOpacity: ' + JXG.Options.opacityLevel + '>>; ';
+                    reset_str = 'delete ' + step.dest_id + '; ';
+                    reset_str += 'delete ' + step.dest_sub_ids[0] + '; ';
+                    break;
+
+                case JXG.GENTYPE_REFLEXANGLE:
+                    set_str = assign + 'reflexangle(' + step.src_ids.join(', ') + ') ';
+                    set_str += '<<';
+                    set_str += 'dot: <<priv:true, id: \'' + step.dest_sub_ids[0] + '\', ';
+                    set_str += 'name: \'' + step.dest_sub_ids[0] + '\'>>, ';
+                    set_str += attrid + ' fillOpacity: ' + JXG.Options.opacityLevel + '>>; ';
+                    reset_str = 'delete ' + step.dest_id + '; ';
+                    reset_str += 'delete ' + step.dest_sub_ids[0] + '; ';
+                    break;
+
                 case JXG.GENTYPE_SLOPETRIANGLE:
                     // step.src_ids[0] may contain one or two parent elements.
-                    set_str = assign + 'slopetriangle(' + step.src_ids[0] + ') <<';
+                    set_str = assign + 'slopetriangle(' + step.src_ids.join(', ') + ') <<';
                     set_str += attrid + ' name: \'\',';
                     set_str += 'borders: <<ids: [\'' + step.dest_sub_ids[4] + '\', \'' + step.dest_sub_ids[5] + '\', \'' + step.dest_sub_ids[6] + '\']>>,';
-                    set_str += 'basepoint: <<id: \'' + step.dest_sub_ids[0] + '\'>>, baseline: <<id: \'' + step.dest_sub_ids[1] + '\'>>,';
-                    set_str += 'glider: <<id: \'' + step.dest_sub_ids[2] + '\'>>, toppoint: <<id: \'' + step.dest_sub_ids[3] + '\'>>';
+                    set_str += 'basepoint: <<id: \'' + step.dest_sub_ids[0] + '\', priv: true >>, baseline: <<id: \'' + step.dest_sub_ids[1] + '\', priv: true >>,';
+                    set_str += 'glider: <<id: \'' + step.dest_sub_ids[2] + '\', priv: true >>, toppoint: <<id: \'' + step.dest_sub_ids[3] + '\', priv: true >>';
+                    if (step.dest_sub_ids.length === 8) {  // The test is needed for backwards compatibility
+                        set_str += ', tangent: <<id: \'' + step.dest_sub_ids[2] + '\', priv: true, point1: <<priv: true >>, point2: <<priv: true >> >>';
+                    }
                     set_str += '>>;';
                     reset_str = 'delete ' + step.dest_id + '; ';
 
@@ -892,9 +978,9 @@
 
                     set_str = assign + step.args.plot_type + '(' + step.args.func;
 
-                    if (isNaN(step.args.a) || step.args.a == null)
+                    if (isNaN(step.args.a) || step.args.a === null || step.args.a === undefined)
                         step.args.a = "-infinity";
-                    if (isNaN(step.args.b) || step.args.b == null)
+                    if (isNaN(step.args.b) || step.args.b ===  null || step.args.b === undefined)
                         step.args.b = "infinity";
 
                     if (step.args.a != step.args.b)
@@ -905,7 +991,7 @@
                     if (step.args.isPolar)
                         set_str += 'curveType: \'polar\', ';
 
-                    set_str += attrid + 'name: \'\', strokeColor: \'' + step.args.color + '\', doAdvancedPlot: true, doAdvancedPlotOld: false >>; ';
+                    set_str += attrid + 'name: \'\', withLabel: true, strokeColor: \'' + step.args.color + '\', doAdvancedPlot: true, doAdvancedPlotOld: false >>; ';
                     reset_str = 'delete ' + step.dest_id + '; ';
 
                     break;
@@ -918,8 +1004,8 @@
                     set_str += 'baseline: <<id: \'';
                     set_str += step.dest_sub_ids[0] + '\', name: \'' + step.dest_sub_ids[0] + '\', priv: true>>, highline: <<id: \'';
                     set_str += step.dest_sub_ids[1] + '\', name: \'' + step.dest_sub_ids[1] + '\', priv: true>>, point1: <<id: \'';
-                    set_str += step.dest_sub_ids[2] + '\', name: \'' + step.dest_sub_ids[2] + '\', priv: true>>, point2: <<id: \'';
-                    set_str += step.dest_sub_ids[3] + '\', name: \'' + step.dest_sub_ids[3] + '\', priv: true>>, label: <<id: \'';
+                    set_str += step.dest_sub_ids[2] + '\', name: \'' + step.dest_sub_ids[2] + '\', priv: false, frozen: true>>, point2: <<id: \'';
+                    set_str += step.dest_sub_ids[3] + '\', name: \'' + step.dest_sub_ids[3] + '\', priv: false, frozen: true>>, label: <<id: \'';
                     set_str += step.dest_sub_ids[4] + '\', name: \'' + step.dest_sub_ids[4] + '\', priv: true>>';
                     set_str += ', name: \'' + step.args.name + '\'>>; ';
 
@@ -974,7 +1060,7 @@
                         } else {
                             arr = this.generateJCode(step_log[step.args.steps[i]], board, step_log);
                         }
-                        
+
                         if (arr.length >= 3 && JXG.trim(arr[2]) !== '') {
                             set_str = arr[2] + set_str;
                         }
@@ -1097,12 +1183,12 @@
                     }
 
                     set_str += step.dest_sub_ids[1] + '.setRadius(function() { return ' + step.args.func + '; }); ';
-                    
+
                     for (j = 0; j < step.src_ids.length; j++) {
                         set_str += step.src_ids[j] + '.addChild(' + step.dest_sub_ids[0] + '); ';
                         set_str += step.src_ids[j] + '.addChild(' + step.dest_sub_ids[1] + '); ';
                     }
-                    
+
                     if (step.args.migrate !== 0 && step.args.migrate !== -1) {
                         set_str += '$board.migratePoint(' + step.dest_sub_ids[0] + ', ' + step.args.migrate + '); ';
                     }
@@ -1111,9 +1197,36 @@
 
                     break;
 
+                case JXG.GENTYPE_VECTORCOPY:
+
+                    xstart = getObject(step.src_ids[0]).coords.usrCoords[1];
+                    ystart = getObject(step.src_ids[0]).coords.usrCoords[2];
+
+                    set_str = 'point(' + pn(xstart - step.args.x) + ', ' + pn(ystart - step.args.y) + ') <<id: \'';
+                    set_str += step.dest_sub_ids[0] + '\', name: \'\', withLabel: false>>; ';
+                    set_str += 'parallelpoint(\'' + step.src_ids[0] + '\',\'' + step.src_ids[1] + '\',\'' + step.dest_sub_ids[0] + '\') <<id: \'' + step.dest_sub_ids[1];
+                    set_str += '\', strokeColor: \'#888888\', visible: true, priv: false, name: \'\', ';
+                    set_str += 'layer: ' + JXG.Options.layer.line + ', opacity: 0.2, withLabel: false>>; ';
+                    set_str += 'arrow(\'' + step.dest_sub_ids[0] + '\',\'' + step.dest_sub_ids[1]  + '\') <<id: \'' + step.dest_sub_ids[2];
+                    set_str += '\', strokeColor: \'#888888\', visible: true, name: \'\', withLabel: false>>; ';
+
+                    for (j = 0; j < step.src_ids.length; j++) {
+                        set_str += step.src_ids[j] + '.addChild(' + step.dest_sub_ids[0] + '); ';
+                        set_str += step.src_ids[j] + '.addChild(' + step.dest_sub_ids[1] + '); ';
+                        set_str += step.src_ids[j] + '.addChild(' + step.dest_sub_ids[2] + '); ';
+                    }
+
+                    if (step.args.migrate !== 0 && step.args.migrate !== -1) {
+                        set_str += '$board.migratePoint(' + step.dest_sub_ids[0] + ', ' + step.args.migrate + '); ';
+                    }
+
+                    reset_str = 'delete ' + step.dest_sub_ids[1] + '; delete ' + step.dest_sub_ids[0] + '; delete ' + step.dest_sub_ids[2] + ';';
+
+                    break;
+
                 case JXG.GENTYPE_MOVEMENT:
 
-                    if (step.args.obj_type === JXG.OBJECT_TYPE_LINE) {
+                    if (step.args.obj_type === JXG.OBJECT_TYPE_LINE || step.args.obj_type === JXG.OBJECT_TYPE_VECTOR) {
                         set_str = step.src_ids[0] + '.move([' + pn(step.args.coords[0].usrCoords[0]) + ', ';
                         set_str += pn(step.args.coords[0].usrCoords[1]) + ', ' + pn(step.args.coords[0].usrCoords[2]) + ']); ';
                         reset_str = step.src_ids[0] + '.move([' + step.args.zstart[0] + ', ' + step.args.xstart[0] + ', ';
@@ -1151,9 +1264,9 @@
                         if (JXG.exists(step.args.coords[0])) {
                             set_str = step.src_ids[0] + '.move([' + pn(step.args.coords[0].usrCoords[1]) + ', ';
                             set_str += pn(step.args.coords[0].usrCoords[2]) + ']); ';
-    
+
                             reset_str = step.src_ids[0] + '.move([' + step.args.xstart + ', ' + step.args.ystart + ']); ';
-                        } 
+                        }
                     }
 
                     break;
