@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2015
+    Copyright 2008-2016
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -156,6 +156,14 @@ define([
          * @type String
          */
         this.type = '';
+
+        /**
+         * True if the browsers' SVG engine supports foreignObject.
+         * Not supporting browsers are IE 9 - 11.
+         * @type Boolean
+         * @private
+         */
+        this.supportsForeignObject = false;
     };
 
     JXG.extend(JXG.AbstractRenderer.prototype, /** @lends JXG.AbstractRenderer.prototype */ {
@@ -175,8 +183,6 @@ define([
          * @private
          */
         _updateVisual: function (element, not, enhanced) {
-            var rgbo;
-
             if (enhanced || this.enhancedRendering) {
                 not = not || {};
 
@@ -341,9 +347,7 @@ define([
                 minlen = 10,
                 margin = null;
 
-            if (element.visProp.firstarrow || element.visProp.lastarrow) {
-                margin = -4;
-            }
+            margin = element.visProp.margin;
             Geometry.calcStraight(element, c1, c2, margin);
 
             d1x = d1y = d2x = d2y = 0.0;
@@ -596,21 +600,41 @@ define([
          * @see JXG.AbstractRenderer#updateTextStyle
          */
         drawText: function (element) {
-            var node, z;
+            var node, z, level;
 
-            if (element.visProp.display === 'html' && Env.isBrowser) {
+            if (element.visProp.display === 'html' && Env.isBrowser && this.type !== 'no') {
                 node = this.container.ownerDocument.createElement('div');
+                //node = this.container.ownerDocument.createElementNS('http://www.w3.org/1999/xhtml', 'div'); //
                 node.style.position = 'absolute';
 
                 node.className = element.visProp.cssclass;
-                if (this.container.style.zIndex === '') {
-                    z = 0;
+
+                /* SVG renderer - beside IE 9-11 - support foreignObject. This
+                   is used to host the HTML. Then, conversion to canvas works also
+                   for HTML text.
+
+                   But to allow interaction with the HTML elements (e.g. buttons) all such texts
+                   have to be in a single foreign object. The reason is our foreign objects have to cover the
+                   whole board and would block event bubbling.
+                 */
+                level = element.visProp.layer;
+                if (!Type.exists(level)) { // trace nodes have level not set
+                    level = 0;
+                }
+                if (!element.visProp.externalhtml && this.supportsForeignObject &&
+                    Type.exists(this.foreignObjLayer[level])) {
+                    this.foreignObjLayer[level].appendChild(node);
                 } else {
-                    z = parseInt(this.container.style.zIndex, 10);
+                    if (this.container.style.zIndex === '') {
+                        z = 0;
+                    } else {
+                        z = parseInt(this.container.style.zIndex, 10);
+                    }
+
+                    node.style.zIndex = z + level;
+                    this.container.appendChild(node);
                 }
 
-                node.style.zIndex = z + element.board.options.layer.text;
-                this.container.appendChild(node);
                 node.setAttribute('id', this.container.id + '_' + element.id);
             } else {
                 node = this.drawInternalText(element);
@@ -632,12 +656,12 @@ define([
          * @see JXG.AbstractRenderer#updateTextStyle
          */
         updateText: function (el) {
-            var content = el.plaintext, v, c;
+            var content = el.plaintext, v, c, parentNode;
 
             if (el.visProp.visible) {
                 this.updateTextStyle(el, false);
 
-                if (el.visProp.display === 'html') {
+                if (el.visProp.display === 'html' && this.type !== 'no') {
                     // Set the position
                     if (!isNaN(el.coords.scrCoords[1] + el.coords.scrCoords[2])) {
 
@@ -654,6 +678,11 @@ define([
                             v = Math.floor(c);
                         }
 
+                        // This may be useful for foreignObj.
+                        //if (window.devicePixelRatio !== undefined) {
+                        //v *= window.devicePixelRatio;
+                        //}
+
                         if (el.visPropOld.left !== (el.visProp.anchorx + v)) {
                             if (el.visProp.anchorx === 'right') {
                                 el.rendNode.style.right = v + 'px';
@@ -677,6 +706,11 @@ define([
                             v = Math.floor(c);
                         }
 
+                        // This may be useful for foreignObj.
+                        //if (window.devicePixelRatio !== undefined) {
+                        //v *= window.devicePixelRatio;
+                        //}
+
                         if (el.visPropOld.top !== (el.visProp.anchory + v)) {
                             if (el.visProp.anchory === 'bottom') {
                                 el.rendNode.style.top = 'auto';
@@ -691,7 +725,17 @@ define([
 
                     // Set the content
                     if (el.htmlStr !== content) {
-                        el.rendNode.innerHTML = content;
+                        try {
+                            el.rendNode.innerHTML = content;
+                        } catch (e) {
+                            // Setting innerHTML sometimes fails in IE8. A workaround is to
+                            // take the node off the DOM, assign innerHTML, then append back.
+                            // Works for text elements as they are absolutely positioned.
+                            parentNode = el.rendNode.parentNode;
+                            el.rendNode.parentNode.removeChild(el.rendNode);
+                            el.rendNode.innerHTML = content;
+                            parentNode.appendChild(el.rendNode);
+                        }
                         el.htmlStr = content;
 
                         if (el.visProp.usemathjax) {
@@ -726,7 +770,7 @@ define([
          * @see JXG.AbstractRenderer#updateInternalTextStyle
          */
         updateTextStyle: function (element, doHighlight) {
-            var fs, so, sc, css,
+            var fs, so, sc, css, node, list,
                 ev = element.visProp,
                 display = Env.isBrowser ? ev.display : 'internal';
 
@@ -745,18 +789,27 @@ define([
                 fs = Type.evaluate(element.visProp.fontsize);
                 if (element.visPropOld.fontsize !== fs) {
                     element.needsSizeUpdate = true;
+                    list = ['rendNode', 'rendNodeTag', 'rendNodeLabel'];
                     try {
-                        element.rendNode.style.fontSize = fs + 'px';
+                        for (node in list) {
+                            if (JXG.exists(element[list[node]])) {
+                                element[list[node]].style.fontSize = fs + 'px';
+                            }
+                        }
                     } catch (e) {
                         // IE needs special treatment.
-                        element.rendNode.style.fontSize = fs;
+                        for (node in list) {
+                            if (JXG.exists(element[list[node]])) {
+                                element[list[node]].style.fontSize = fs;
+                            }
+                        }
                     }
                     element.visPropOld.fontsize = fs;
                 }
 
             }
 
-            if (display === 'html') {
+            if (display === 'html' && this.type !== 'no') {
                 if (element.visPropOld.cssclass !== css) {
                     element.rendNode.className = css;
                     element.visPropOld.cssclass = css;
@@ -1169,7 +1222,8 @@ define([
                 if (element.type === Const.OBJECT_TYPE_POLYGON) {
                     this.setObjectFillColor(element, ev.highlightfillcolor, ev.highlightfillopacity);
                     for (i = 0; i < element.borders.length; i++) {
-                        this.setObjectStrokeColor(element.borders[i], element.borders[i].visProp.highlightstrokecolor,
+                        this.setObjectStrokeColor(element.borders[i],
+                            element.borders[i].visProp.highlightstrokecolor,
                             element.borders[i].visProp.highlightstrokeopacity);
                     }
                 } else {
@@ -1177,6 +1231,7 @@ define([
                         this.updateTextStyle(element, true);
                     } else if (element.type === Const.OBJECT_TYPE_IMAGE) {
                         this.updateImageStyle(element, true);
+                        this.setObjectFillColor(element, ev.highlightfillcolor, ev.highlightfillopacity);
                     } else {
                         this.setObjectStrokeColor(element, ev.highlightstrokecolor, ev.highlightstrokeopacity);
                         this.setObjectFillColor(element, ev.highlightfillcolor, ev.highlightfillopacity);
@@ -1211,6 +1266,7 @@ define([
                         this.updateTextStyle(element, false);
                     } else if (element.type === Const.OBJECT_TYPE_IMAGE) {
                         this.updateImageStyle(element, false);
+                        this.setObjectFillColor(element, ev.fillcolor, ev.fillopacity);
                     } else {
                         this.setObjectStrokeColor(element, ev.strokecolor, ev.strokeopacity);
                         this.setObjectFillColor(element, ev.fillcolor, ev.fillopacity);
@@ -1275,7 +1331,7 @@ define([
                         this.style.backgroundColor = board.options.navbar.fillColor;
                     }, button);
 
-                    Env.addEvent(button, 'click', handler, board);
+                    Env.addEvent(button, 'click', function(e) { (Type.bind(handler, board))(); return false; }, board);
                     // prevent the click from bubbling down to the board
                     Env.addEvent(button, 'mouseup', cancelbubble, board);
                     Env.addEvent(button, 'mousedown', cancelbubble, board);
@@ -1283,7 +1339,7 @@ define([
                     Env.addEvent(button, 'touchstart', cancelbubble, board);
                 };
 
-            if (Env.isBrowser) {
+            if (Env.isBrowser && this.type !== 'no') {
                 doc = board.containerObj.ownerDocument;
                 node = doc.createElement('div');
 
@@ -1393,7 +1449,15 @@ define([
          * @param {Number} i Number of the crosshair to show
          * @param {Array} pos New positon in screen coordinates
          */
-        updateTouchpoint: function (i, pos) {}
+        updateTouchpoint: function (i, pos) {},
+
+        /**
+         * Convert SVG construction to canvas.
+         * Only available on SVGRenderer.
+         *
+         * @see JXG.SVGRenderer#dumpToCanvas
+         */
+        dumpToCanvas: function(canvasId) {}
     });
 
     return JXG.AbstractRenderer;
