@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2015
+    Copyright 2008-2016
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -601,7 +601,7 @@ define([
             // el.rendNode.setAttributeNS(null, "class", el.visProp.cssclass);
             if (this._setColor(el, 'stroke', 'fill') && !isNaN(el.coords.scrCoords[1] + el.coords.scrCoords[2])) {
                 if (el.visProp.fontsize) {
-                    if (typeof el.visProp.fontsize === 'function') {
+                    if (Type.isFunction(el.visProp.fontsize)) {
                         fs = el.visProp.fontsize();
                         context.font = (fs > 0 ? fs : 0) + 'px Arial';
                     } else {
@@ -1073,7 +1073,7 @@ define([
             this.context.save();
             this.context.clearRect(0, 0, this.canvasRoot.width, this.canvasRoot.height);
 
-            if (board && board.showCopyright) {
+            if (board && board.attr.showcopyright) {
                 this.displayCopyright(JXG.licenseText, 12);
             }
         },
