@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2015
+    Copyright 2008-2016
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -44,8 +44,8 @@
 */
 
 define([
-    'jxg', 'options', 'renderer/abstract', 'base/constants', 'utils/type', 'utils/env', 'utils/color', 'math/numerics'
-], function (JXG, Options, AbstractRenderer, Const, Type, Env, Color, Numerics) {
+    'jxg', 'options', 'renderer/abstract', 'base/constants', 'utils/type', 'utils/env', 'utils/color', 'utils/base64', 'math/numerics'
+], function (JXG, Options, AbstractRenderer, Const, Type, Env, Color, Base64, Numerics) {
 
     "use strict";
 
@@ -103,8 +103,9 @@ define([
         this.svgRoot = this.container.ownerDocument.createElementNS(this.svgNamespace, "svg");
         this.svgRoot.style.overflow = 'hidden';
 
-        this.svgRoot.style.width = dim.width + 'px';
-        this.svgRoot.style.height = dim.height + 'px';
+        this.resize(dim.width, dim.height);
+
+        //this.svgRoot.setAttributeNS(null, 'shape-rendering', 'crispEdge'); //'optimizeQuality'); //geometricPrecision');
 
         this.container.appendChild(this.svgRoot);
 
@@ -167,6 +168,23 @@ define([
             this.svgRoot.appendChild(this.layer[i]);
         }
 
+        // already documented in JXG.AbstractRenderer
+        this.supportsForeignObject = document.implementation.hasFeature("www.http://w3.org/TR/SVG11/feature#Extensibility", "1.1");
+        if (this.supportsForeignObject) {
+            this.foreignObjLayer = [];
+            for (i = 0; i < Options.layer.numlayers; i++) {
+                if (i === Options.layer.text || i === 0) {    // 0 is for traces
+                    this.foreignObjLayer[i] = this.container.ownerDocument.createElementNS(this.svgNamespace, 'foreignObject');
+
+                    this.foreignObjLayer[i].setAttribute("x",0);
+                    this.foreignObjLayer[i].setAttribute("y",0);
+                    this.foreignObjLayer[i].setAttribute("width","100%");
+                    this.foreignObjLayer[i].setAttribute("height","100%");
+                    this.layer[i].appendChild(this.foreignObjLayer[i]);
+                }
+            }
+        }
+
         /**
          * Defines dash patterns. Defined styles are: <ol>
          * <li value="-1"> 2px dash, 2px space</li>
@@ -214,7 +232,7 @@ define([
             node2.setAttributeNS(null, 'markerUnits', 'strokeWidth'); // 'strokeWidth' 'userSpaceOnUse');
 
             /*
-            * Changes here are also necessary in _setArrowAtts()
+            * Changes here are also necessary in _setArrowWidth()
             */
             s = parseInt(element.visProp.strokewidth, 10);
             //node2.setAttributeNS(null, 'viewBox', (-s) + ' ' + (-s) + ' ' + s * 12 + ' ' + s * 12);
@@ -246,21 +264,38 @@ define([
         },
 
         /**
-         * Updates an arrow DOM node.
+         * Updates color of an arrow DOM node.
          * @param {Node} node The arrow node.
          * @param {String} color Color value in a HTML compatible format, e.g. <tt>#00ff00</tt> or <tt>green</tt> for green.
          * @param {Number} opacity
-         * @param {Number} width
          */
-        _setArrowAtts: function (node, color, opacity, width, parentNode) {
+        _setArrowColor: function (node, color, opacity, parentNode) {
             var s, d;
 
             if (node) {
-                node.setAttributeNS(null, 'stroke', color);
+                if (Type.isString(color)) {
+                    node.setAttributeNS(null, 'stroke', color);
+                    node.setAttributeNS(null, 'fill', color);
+                }
                 node.setAttributeNS(null, 'stroke-opacity', opacity);
-                node.setAttributeNS(null, 'fill', color);
                 node.setAttributeNS(null, 'fill-opacity', opacity);
 
+                if (this.isIE) {
+                    parentNode.parentNode.insertBefore(parentNode, parentNode);
+                }
+            }
+
+        },
+
+        /**
+         * Updates width of an arrow DOM node.
+         * @param {Node} node The arrow node.
+         * @param {Number} width
+         */
+        _setArrowWidth: function (node, width, parentNode) {
+            var s, d;
+
+            if (node) {
                 // This is the stroke-width of the arrow head.
                 // Should be zero to make the positioning easy
                 node.setAttributeNS(null, 'stroke-width', 0);
@@ -303,7 +338,7 @@ define([
                 x = c[0];
                 y = c[1];
 
-                if (typeof x[0] === 'number' && typeof x[1] === 'number') {
+                if (Type.isNumber(x[0]) && Type.isNumber(x[1])) {
                     tickStr += "M " + (x[0]) + " " + (y[0]) + " L " + (x[1]) + " " + (y[1]) + " ";
                 }
             }
@@ -345,7 +380,7 @@ define([
             node.setAttributeNS(null, "class", el.visProp.cssclass);
             //node.setAttributeNS(null, "style", "alignment-baseline:middle"); // Not yet supported by Firefox
 
-            // Preserve spaces 
+            // Preserve spaces
             node.setAttributeNS("http://www.w3.org/XML/1998/namespace", "space", "preserve");
 
             el.rendNodeText = this.container.ownerDocument.createTextNode('');
@@ -541,7 +576,9 @@ define([
         updateEllipsePrim: function (node, x, y, rx, ry) {
             var huge = 1000000;
 
+            huge = 200000; // IE
             // webkit does not like huge values if the object is dashed
+            // iE doesn't like huge values above 216000
             x = Math.abs(x) < huge ? x : huge * x / Math.abs(x);
             y = Math.abs(y) < huge ? y : huge * y / Math.abs(y);
             rx = Math.abs(rx) < huge ? rx : huge * rx / Math.abs(rx);
@@ -557,8 +594,10 @@ define([
         updateLinePrim: function (node, p1x, p1y, p2x, p2y) {
             var huge = 1000000;
 
+            huge = 200000; //IE
             if (!isNaN(p1x + p1y + p2x + p2y)) {
                 // webkit does not like huge values if the object is dashed
+                // IE doesn't like huge values above 216000
                 p1x = Math.abs(p1x) < huge ? p1x : huge * p1x / Math.abs(p1x);
                 p1y = Math.abs(p1y) < huge ? p1y : huge * p1y / Math.abs(p1y);
                 p2x = Math.abs(p2x) < huge ? p2x : huge * p2x / Math.abs(p2x);
@@ -916,7 +955,7 @@ define([
         },
 
         // documented in JXG.AbstractRenderer
-        setObjectFillColor: function (el, color, opacity) {
+        setObjectFillColor: function (el, color, opacity, rendNode) {
             var node, c, rgbo, oo,
                 rgba = Type.evaluate(color),
                 o = Type.evaluate(opacity);
@@ -926,6 +965,7 @@ define([
             if (el.visPropOld.fillcolor === rgba && el.visPropOld.fillopacity === o) {
                 return;
             }
+
             if (Type.exists(rgba) && rgba !== false) {
                 if (rgba.length !== 9) {          // RGB, not RGBA
                     c = rgba;
@@ -936,18 +976,24 @@ define([
                     oo = o * rgbo[1];
                 }
 
-                node = el.rendNode;
-
-                if (c !== 'none') {               // problem in firefox 17
-                    node.setAttributeNS(null, 'fill', c);
+                if (rendNode === undefined) {
+                    node = el.rendNode;
                 } else {
-                    oo = 0;
+                    node = rendNode;
+                }
+
+                if (c !== 'none') {
+                    node.setAttributeNS(null, 'fill', c);
                 }
 
                 if (el.type === JXG.OBJECT_TYPE_IMAGE) {
                     node.setAttributeNS(null, 'opacity', oo);
-                    //node.style['opacity'] = oo;  // This would overwrite values set y CSS class.
+                    //node.style['opacity'] = oo;  // This would overwrite values set by CSS class.
                 } else {
+                    if (c === 'none') {  // This is don only for non-images
+                                         // because images have no fill color.
+                        oo = 0;
+                    }
                     node.setAttributeNS(null, 'fill-opacity', oo);
                 }
 
@@ -997,14 +1043,15 @@ define([
                 }
 
                 if (el.type === Const.OBJECT_TYPE_ARROW) {
-                    this._setArrowAtts(el.rendNodeTriangle, c, oo, el.visProp.strokewidth, el.rendNode);
-                } else if (el.elementClass === Const.OBJECT_CLASS_CURVE || el.elementClass === Const.OBJECT_CLASS_LINE) {
+                    this._setArrowColor(el.rendNodeTriangle, c, oo, el.rendNode);
+                } else if (el.elementClass === Const.OBJECT_CLASS_CURVE ||
+                            el.elementClass === Const.OBJECT_CLASS_LINE) {
                     if (el.visProp.firstarrow) {
-                        this._setArrowAtts(el.rendNodeTriangleStart, c, oo, el.visProp.strokewidth, el.rendNode);
+                        this._setArrowColor(el.rendNodeTriangleStart, c, oo, el.rendNode);
                     }
 
                     if (el.visProp.lastarrow) {
-                        this._setArrowAtts(el.rendNodeTriangleEnd, c, oo, el.visProp.strokewidth, el.rendNode);
+                        this._setArrowColor(el.rendNodeTriangleEnd, c, oo, el.rendNode);
                     }
                 }
             }
@@ -1016,7 +1063,8 @@ define([
         // documented in JXG.AbstractRenderer
         setObjectStrokeWidth: function (el, width) {
             var node,
-                w = Type.evaluate(width);
+                w = Type.evaluate(width),
+                rgba, c, rgbo, o, oo;
 
             if (isNaN(w) || el.visPropOld.strokewidth === w) {
                 return;
@@ -1028,17 +1076,18 @@ define([
                 this.setPropertyPrim(node, 'stroke-width', w + 'px');
 
                 if (el.type === Const.OBJECT_TYPE_ARROW) {
-                    this._setArrowAtts(el.rendNodeTriangle, el.visProp.strokecolor, el.visProp.strokeopacity, w, el.rendNode);
-                } else if (el.elementClass === Const.OBJECT_CLASS_CURVE || el.elementClass === Const.OBJECT_CLASS_LINE) {
+                    this._setArrowWidth(el.rendNodeTriangle, w, el.rendNode);
+                } else if (el.elementClass === Const.OBJECT_CLASS_CURVE ||
+                            el.elementClass === Const.OBJECT_CLASS_LINE) {
                     if (el.visProp.firstarrow) {
-                        this._setArrowAtts(el.rendNodeTriangleStart, el.visProp.strokecolor, el.visProp.strokeopacity, w, el.rendNode);
+                        this._setArrowWidth(el.rendNodeTriangleStart, w, el.rendNode);
                     }
 
                     if (el.visProp.lastarrow) {
-                        this._setArrowAtts(el.rendNodeTriangleEnd, el.visProp.strokecolor, el.visProp.strokeopacity, w, el.rendNode);
+                        this._setArrowWidth(el.rendNodeTriangleEnd, w, el.rendNode);
                     }
                 }
-            }
+             }
             el.visPropOld.strokewidth = w;
         },
 
@@ -1079,6 +1128,8 @@ define([
         resize: function (w, h) {
             this.svgRoot.style.width = parseFloat(w) + 'px';
             this.svgRoot.style.height = parseFloat(h) + 'px';
+            this.svgRoot.setAttribute("width", parseFloat(w));
+            this.svgRoot.setAttribute("height", parseFloat(h));
         },
 
         // documented in JXG.AbstractRenderer
@@ -1146,7 +1197,50 @@ define([
                     'L ' + x + ' ' + (y + d));
                 this.updateEllipsePrim(this.touchpoints[2 * i + 1], pos[0], pos[1], 25, 25);
             }
+        },
+
+        /**
+         * Convert the SVG construction into an HTML canvas image.
+         * This works for all SVG supporting browsers.
+         * For IE it works from version 9.
+         * But HTML texts are ignored on IE. The drawing is done with a delay of
+         * 200 ms. Otherwise there are problems with IE.
+         *
+         * @param  {String} canvasId Id of an HTML canvas element
+         * @returns {Object}          the svg renderer object.
+         *
+         * @example
+         * 	board.renderer.dumpToCanvas('canvas');
+         */
+        dumpToCanvas: function(canvasId) {
+            var svgRoot = this.svgRoot,
+                btoa = window.btoa || Base64.encode,
+                svg, tmpImg, cv, ctx;
+
+            svgRoot.setAttribute("xmlns", "http://www.w3.org/2000/svg");
+            svg = new XMLSerializer().serializeToString(svgRoot);
+
+            // In IE we have to remove the namespace again.
+            if ((svg.match(/xmlns=\"http:\/\/www.w3.org\/2000\/svg\"/g) || []).length > 1) {
+                svg = svg.replace(/xmlns=\"http:\/\/www.w3.org\/2000\/svg\"/, '');
+            }
+
+            cv = document.getElementById(canvasId);
+            ctx = cv.getContext("2d");
+
+            tmpImg = new Image();
+            tmpImg.onload = function () {
+                // IE needs a pause...
+                setTimeout(function(){
+                    cv.width = cv.width;
+                    ctx.drawImage(tmpImg, 0, 0);
+                }, 200);
+            };
+            tmpImg.src = 'data:image/svg+xml;base64,' + btoa(unescape(encodeURIComponent(svg)));
+
+            return this;
         }
+
     });
 
     return JXG.SVGRenderer;
