@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2015
+    Copyright 2008-2016
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -85,13 +85,12 @@ define(['jxg', 'utils/type'], function (JXG, Type) {
          * @returns {Boolean} True, if the browser supports HTML canvas.
          */
         supportsCanvas: function () {
-            var c,
-                hasCanvas = false;
+            var c, hasCanvas = false;
 
             if (this.isNode()) {
                 try {
                     c = (typeof module === 'object' ? module.require('canvas') : require('canvas'));
-                    hasCanvas = true;
+                    hasCanvas = !!c;
                 } catch (err) { }
             }
 
@@ -124,7 +123,7 @@ define(['jxg', 'utils/type'], function (JXG, Type) {
 
         /**
          * Checks if the environments supports the W3C Pointer Events API {@link http://www.w3.org/Submission/pointer-events/}
-         * @return {Boolean}
+         * @returns {Boolean}
          */
         supportsPointerEvents: function () {
             return JXG.isBrowser && window.navigator && (window.navigator.msPointerEnabled || window.navigator.pointerEnabled);
@@ -172,7 +171,7 @@ define(['jxg', 'utils/type'], function (JXG, Type) {
 
         /**
          * Returns true if the run inside a Windows 8 "Metro" App.
-         * @return {Boolean}
+         * @returns {Boolean}
          */
         isMetroApp: function () {
             return typeof window === 'object' && window.clientInformation && window.clientInformation.appVersion && window.clientInformation.appVersion.indexOf('MSAppHost') > -1;
@@ -251,15 +250,16 @@ define(['jxg', 'utils/type'], function (JXG, Type) {
 
             // Work around a bug in Safari
             if (display !== 'none' && display !== null) {
-                if (element.offsetWidth > 0 && element.offsetHeight > 0) {
-                    return {width: element.offsetWidth, height: element.offsetHeight};
-                } else { // a parent might be set to display:none; try reading them from styles
-                    style = window.getComputedStyle ? window.getComputedStyle(element) : element.style;
-                    return {
-                        width: pixelDimRegExp.test(style.width) ? parseFloat(style.width) : 0,
-                        height: pixelDimRegExp.test(style.height) ? parseFloat(style.height) : 0
-                    };
+                if (element.clientWidth > 0 && element.clientHeight > 0) {
+                    return {width: element.clientWidth, height: element.clientHeight};
                 }
+
+                // a parent might be set to display:none; try reading them from styles
+                style = window.getComputedStyle ? window.getComputedStyle(element) : element.style;
+                return {
+                    width: pixelDimRegExp.test(style.width) ? parseFloat(style.width) : 0,
+                    height: pixelDimRegExp.test(style.height) ? parseFloat(style.height) : 0
+                };
             }
 
             // All *Width and *Height properties give 0 on elements with display set to none,
@@ -429,12 +429,11 @@ define(['jxg', 'utils/type'], function (JXG, Type) {
                 }
             }
 
-            if (e.pageX || e.pageY) {
-                posx = e.pageX;
-                posy = e.pageY;
-            } else if (e.clientX || e.clientY) {
-                posx = e.clientX + doc.body.scrollLeft + doc.documentElement.scrollLeft;
-                posy = e.clientY + doc.body.scrollTop + doc.documentElement.scrollTop;
+            // Scrolling is ignored.
+            // e.clientX is supported since IE6
+            if (e.clientX) {
+                posx = e.clientX;
+                posy = e.clientY;
             }
 
             return [posx, posy];
@@ -501,12 +500,11 @@ define(['jxg', 'utils/type'], function (JXG, Type) {
          * @returns The value of the CSS property and <tt>undefined</tt> if it is not set.
          */
         getStyle: function (obj, stylename) {
-            var r, doc;
-
-            doc = obj.ownerDocument;
+            var r,
+                doc = obj.ownerDocument;
 
             // Non-IE
-            if (window.getComputedStyle) {
+            if (doc.defaultView && doc.defaultView.getComputedStyle) {
                 r = doc.defaultView.getComputedStyle(obj, null).getPropertyValue(stylename);
             // IE
             } else if (obj.currentStyle && JXG.ieVersion >= 9) {
@@ -593,22 +591,34 @@ define(['jxg', 'utils/type'], function (JXG, Type) {
 
         /**
          * Scaling CSS transformations applied to the div element containing the JSXGraph constructions
-         * are determined. Not implemented are 'rotate', 'skew', 'skewX', 'skewY'.
-         * @returns {Array} 3x3 transformation matrix. See {@link JXG.Board#updateCSSTransforms}.
+         * are determined. In IE prior to 9, 'rotate', 'skew', 'skewX', 'skewY' are not supported.
+         * @returns {Array} 3x3 transformation matrix without translation part. See {@link JXG.Board#updateCSSTransforms}.
          */
         getCSSTransformMatrix: function (obj) {
             var i, j, str, arrstr, start, len, len2, arr,
+                st, tr,
+                doc = obj.ownerDocument,
                 t = ['transform', 'webkitTransform', 'MozTransform', 'msTransform', 'oTransform'],
                 mat = [[1, 0, 0],
                     [0, 1, 0],
                     [0, 0, 1]];
 
-            // Take the first transformation matrix
-            len = t.length;
-            for (i = 0, str = ''; i < len; i++) {
-                if (Type.exists(obj.style[t[i]])) {
-                    str = obj.style[t[i]];
-                    break;
+            // This should work on all browsers except IE 6-8
+            if (doc.defaultView && doc.defaultView.getComputedStyle) {
+                st = doc.defaultView.getComputedStyle(obj, null);
+                str = st.getPropertyValue("-webkit-transform") ||
+                     st.getPropertyValue("-moz-transform") ||
+                     st.getPropertyValue("-ms-transform") ||
+                     st.getPropertyValue("-o-transform") ||
+                     st.getPropertyValue("transform");
+            } else {
+                // Take the first transformation matrix
+                len = t.length;
+                for (i = 0, str = ''; i < len; i++) {
+                    if (Type.exists(obj.style[t[i]])) {
+                        str = obj.style[t[i]];
+                        break;
+                    }
                 }
             }
 
@@ -628,7 +638,6 @@ define(['jxg', 'utils/type'], function (JXG, Type) {
                         mat = [[1, 0, 0],
                             [0, arr[0], arr[1]],
                             [0, arr[2], arr[3]]];
-                        // Missing are rotate, skew, skewX, skewY
                     } else if (str.indexOf('scaleX') === 0) {
                         mat[1][1] = arr[0];
                     } else if (str.indexOf('scaleY') === 0) {
