@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2015
+    Copyright 2008-2016
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -58,7 +58,7 @@ define([
          * @returns {Boolean}
          */
         isId: function (board, s) {
-            return typeof s === 'string' && !!board.objects[s];
+            return (typeof s === 'string') && !!board.objects[s];
         },
 
         /**
@@ -140,7 +140,7 @@ define([
          * @returns {Boolean} True, if v is of type JXG.Point.
          */
         isPoint: function (v) {
-            if (typeof v === 'object') {
+            if (v !== null && typeof v === 'object') {
                 return (v.elementClass === Const.OBJECT_CLASS_POINT);
             }
 
@@ -150,13 +150,13 @@ define([
         /**
          * Checks if a given variable is a reference of a JSXGraph Point element or an array of length at least two or
          * a function returning an array of length two or three.
+         * @param {JXG.Board} board
          * @param v A variable of any type.
          * @returns {Boolean} True, if v is of type JXG.Point.
          */
-        isPointType: function (v, board) {
+        isPointType: function (board, v) {
             var val;
 
-            v = board.select(v);
             if (this.isArray(v)) {
                 return true;
             }
@@ -166,6 +166,7 @@ define([
                     return true;
                 }
             }
+            v = board.select(v);
             return this.isPoint(v);
         },
 
@@ -227,7 +228,7 @@ define([
          * to evaluate.
          */
         createEvalFunction: function (board, param, n) {
-            var f = [], i, str;
+            var f = [], i;
 
             for (i = 0; i < n; i++) {
                 f[i] = JXG.createFunction(param[i], board, '', true);
@@ -285,8 +286,8 @@ define([
 
         /**
          *  Test if the parents array contains existing points. If instead parents contains coordinate arrays or function returning coordinate arrays
-         *  free points with these coordinates are created. 
-         * 
+         *  free points with these coordinates are created.
+         *
          * @param {JXG.Board} board Board object
          * @param {Array} parents Array containing parent elements for a new object. This array may contain
          *    <ul>
@@ -297,7 +298,7 @@ define([
          *      <li> Coordinates of points given as array of functions of length two or three. Each function returns one coordinate, e.g.
          *           [function(){ return 2; }, function(){ return 3; }]
          *      <li> Function returning coordinates, e.g. function() { return [2, 3]; }
-         *    </ul>  
+         *    </ul>
          *  In the last three cases a new point will be created.
          * @param {String} attrClass Main attribute class of newly created points, see {@link JXG@copyAttributes}
          * @param {Array} attrArray List of subtype attributes for the newly created points. The list of subtypes is mapped to the list of new points.
@@ -307,7 +308,7 @@ define([
             var i, j,
                 len,
                 lenAttr = 0,
-                points = [], attr, p, val;
+                points = [], attr, val;
 
             if (!this.isArray(parents)) {
                 parents = [parents];
@@ -534,7 +535,12 @@ define([
             }
 
             for (i = 0; i < a1.length; i++) {
-                if (a1[i] !== a2[i]) {
+                if (this.isArray(a1[i]) && this.isArray(a2[i])) {
+                    if (!this.cmpArrays(a1[i], a2[i])) {
+                        return false;
+                    }
+                }
+                else if (a1[i] !== a2[i]) {
                     return false;
                 }
             }
@@ -572,8 +578,8 @@ define([
 
             /*jslint bitwise: true*/
 
-            /* 
-             * The performance gain of this bitwise trick is marginal and the behavior 
+            /*
+             * The performance gain of this bitwise trick is marginal and the behavior
              * is different from toFixed: toFixed rounds, the bitweise operation truncateds
              */
             //if (p === 0) {
@@ -671,7 +677,6 @@ define([
             /*jslint forin:false*/
             /*jshint forin:false*/
 
-
             return cObj;
         },
 
@@ -724,7 +729,7 @@ define([
          * @returns {Object} copy of obj or merge of obj and obj2.
          */
         deepCopy: function (obj, obj2, toLower) {
-            var c, i, prop, j, i2;
+            var c, i, prop, i2;
 
             toLower = toLower || false;
 
@@ -733,15 +738,19 @@ define([
             }
 
             // missing hasOwnProperty is on purpose in this function
-            /*jslint forin:true*/
-            /*jshint forin:false*/
-
             if (this.isArray(obj)) {
                 c = [];
                 for (i = 0; i < obj.length; i++) {
                     prop = obj[i];
                     if (typeof prop === 'object') {
-                        c[i] = this.deepCopy(prop);
+                        // We certainly do not want to recurse into a JSXGraph object.
+                        // This would for sure result in an infinite recursion.
+                        // As alternative we copy the id of the object.
+                        if (this.exists(prop.board)) {
+                            c[i] = prop.id;
+                        } else {
+                            c[i] = this.deepCopy(prop);
+                        }
                     } else {
                         c[i] = prop;
                     }
@@ -750,10 +759,13 @@ define([
                 c = {};
                 for (i in obj) {
                     i2 = toLower ? i.toLowerCase() : i;
-
                     prop = obj[i];
-                    if (typeof prop === 'object') {
-                        c[i2] = this.deepCopy(prop);
+                    if (prop !== null && typeof prop === 'object') {
+                        if (this.exists(prop.board)) {
+                            c[i2] = prop.id;
+                        } else {
+                            c[i2] = this.deepCopy(prop);
+                        }
                     } else {
                         c[i2] = prop;
                     }
@@ -775,9 +787,6 @@ define([
                 }
             }
 
-            /*jslint forin:false*/
-            /*jshint forin:true*/
-
             return c;
         },
 
@@ -868,11 +877,11 @@ define([
 
         /**
          * Copy all prototype methods from object "superObject" to object
-         * "subObject". The constructor of superObject will be available 
+         * "subObject". The constructor of superObject will be available
          * in subObject as subObject.constructor[constructorName].
          * @param {Object} subObj A JavaScript object which receives new methods.
          * @param {Object} superObj A JavaScript object which lends its prototype methods to subObject
-         * @returns {String} constructorName Under this name the constructor of superObj will be available 
+         * @returns {String} constructorName Under this name the constructor of superObj will be available
          * in subObject.
          * @private
          */
@@ -1122,7 +1131,7 @@ define([
          */
         sanitizeHTML: function (str, caja) {
             if (typeof html_sanitize === 'function' && caja) {
-                return html_sanitize(str, function () { return; }, function (id) { return id; });
+                return html_sanitize(str, function () {}, function (id) { return id; });
             }
 
             if (str) {
@@ -1135,10 +1144,10 @@ define([
         /**
          * If <tt>s</tt> is a slider, it returns the sliders value, otherwise it just returns the given value.
          * @param {*} s
-         * @retusn {*} s.Value() if s is an element of type slider, s otherwise
+         * @returns {*} s.Value() if s is an element of type slider, s otherwise
          */
         evalSlider: function (s) {
-            if (s.type === Const.OBJECT_TYPE_GLIDER && typeof s.Value === 'function') {
+            if (s && s.type === Const.OBJECT_TYPE_GLIDER && typeof s.Value === 'function') {
                 s = s.Value();
             }
 
